@@ -79,7 +79,9 @@ static int acpiinfo_test1(fwts_framework *fw)
 
 		sscanf(str, "%6d", &yearmonth);
 
-		if (yearmonth > 201902) {
+		if (yearmonth > 202103) {
+			version = 6.4;
+		} else if (yearmonth > 201902) {
 			version = 6.3;
 		} else if (yearmonth > 201609) {
 			version = 6.2;
@@ -109,7 +111,6 @@ static int acpiinfo_test1(fwts_framework *fw)
 static int acpiinfo_test2(fwts_framework *fw)
 {
 	fwts_acpi_table_info *table;
-	fwts_acpi_table_fadt *fadt;
 	uint8_t major;
 	uint8_t minor = 0;
 
@@ -119,11 +120,7 @@ static int acpiinfo_test2(fwts_framework *fw)
 	if (table == NULL || table->data == NULL)
 		return FWTS_ERROR;
 
-	fadt = (fwts_acpi_table_fadt *)table->data;
-
-	major = fadt->header.revision;
-	if (major >= 5 && fadt->header.length >= 268)
-		minor = fadt->minor_version;
+	fwts_get_fadt_version(fw, &major, &minor);
 
 	fwts_log_info(fw,
 		"FACP ACPI Version: %" PRIu8 ".%" PRIu8, major, minor);
@@ -165,6 +162,6 @@ static fwts_framework_ops acpiinfo_ops = {
 	.minor_tests = acpiinfo_tests
 };
 
-FWTS_REGISTER("acpiinfo", &acpiinfo_ops, FWTS_TEST_EARLY, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("acpiinfo", &acpiinfo_ops, FWTS_TEST_EARLY, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
