@@ -96,10 +96,10 @@ static void asf_check_info(
 			info->min_sensor_poll_wait_time);
 	}
 
-	fwts_acpi_reserved_bits_check("ASF!", "ASF_INFO Feature Flags", info->flags, 1, 7, passed);
-	fwts_acpi_reserved_zero_check("ASF!", "ASF_INFO Reserved1", info->reserved1, passed);
-	fwts_acpi_reserved_zero_check("ASF!", "ASF_INFO Reserved2", info->reserved2, passed);
-	fwts_acpi_reserved_zero_check("ASF!", "ASF_INFO Reserved3", info->reserved3, passed);
+	fwts_acpi_reserved_bits("ASF!", "ASF_INFO Feature Flags", info->flags, 1, 7, passed);
+	fwts_acpi_reserved_zero("ASF!", "ASF_INFO Reserved1", info->reserved1, passed);
+	fwts_acpi_reserved_zero("ASF!", "ASF_INFO Reserved2", info->reserved2, passed);
+	fwts_acpi_reserved_zero("ASF!", "ASF_INFO Reserved3", info->reserved3, passed);
 
 	if (*passed)
 		fwts_passed(fw, "No issues found in ASF! ASF_INFO record.");
@@ -457,7 +457,7 @@ static int asf_test1(fwts_framework *fw)
 		fwts_log_info_verbatim(fw, "Length:                     0x%4.4" PRIx16, asf_hdr->length);
 #endif
 
-		fwts_acpi_reserved_zero_check("ASF!", "Information Record Reserved", asf_hdr->reserved, &passed);
+		fwts_acpi_reserved_zero("ASF!", "Information Record Reserved", asf_hdr->reserved, &passed);
 
 		if (asf_hdr->length > (uint32_t)length) {
 			passed = false;
@@ -540,6 +540,6 @@ static fwts_framework_ops asf_ops = {
 	.minor_tests = asf_tests
 };
 
-FWTS_REGISTER("asf", &asf_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("asf", &asf_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
