@@ -38,7 +38,7 @@ static int aspt_test1(fwts_framework *fw)
 	bool passed = true;
 	fwts_acpi_table_aspt *aspt = (fwts_acpi_table_aspt *)table->data;
 
-	if (!fwts_acpi_table_length_check(fw, "ASPT", table->length, sizeof(fwts_acpi_table_aspt))) {
+	if (!fwts_acpi_table_length(fw, "ASPT", table->length, sizeof(fwts_acpi_table_aspt))) {
 		passed = false;
 		goto done;
 	}
@@ -87,6 +87,6 @@ static fwts_framework_ops aspt_ops = {
 	.minor_tests = aspt_tests
 };
 
-FWTS_REGISTER("aspt", &aspt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("aspt", &aspt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
