@@ -35,8 +35,8 @@ static int boot_init(fwts_framework *fw)
 		fwts_log_error(fw, "Cannot read ACPI tables.");
 		return FWTS_ERROR;
 	}
-	if (fwts_firmware_detect() == FWTS_FIRMWARE_UEFI) {
-		fwts_log_error(fw, "ACPI BOOT table is depreciated on UEFI firmware, skipping test");
+	if (fw->firmware_type == FWTS_FIRMWARE_UEFI) {
+		fwts_log_error(fw, "ACPI BOOT table is deprecated on UEFI firmware, skipping test");
 		return FWTS_SKIP;
 	}
 	if (table == NULL || (table && table->length == 0)) {
@@ -56,7 +56,7 @@ static int boot_test1(fwts_framework *fw)
 	bool passed = true;
 	fwts_acpi_table_boot *boot = (fwts_acpi_table_boot *)table->data;
 
-	if (!fwts_acpi_table_length_check(fw, "BOOT", table->length, sizeof(fwts_acpi_table_boot))) {
+	if (!fwts_acpi_table_length(fw, "BOOT", table->length, sizeof(fwts_acpi_table_boot))) {
 		passed = false;
 		goto done;
 	}
@@ -107,6 +107,6 @@ static fwts_framework_ops boot_ops = {
 	.minor_tests = boot_tests
 };
 
-FWTS_REGISTER("boot", &boot_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("boot", &boot_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
