@@ -18,8 +18,6 @@
  */
 #include "fwts.h"
 
-#if defined(FWTS_HAS_ACPI)
-
 #include "brightness-helper.h"
 
 #include <stdlib.h>
@@ -55,7 +53,7 @@ const char *brightness_get_path(void)
 /*
  *  brightness_init()
  *	generic brightness test init, if successful
- *	it opens a diretory for the /sys interface
+ *	it opens a directory for the /sys interface
  */
 int brightness_init(fwts_framework *fw)
 {
@@ -145,5 +143,3 @@ int brightness_set_setting(const char *entry_name, const char *setting, const in
 
 	return FWTS_OK;
 }
-
-#endif
