@@ -66,7 +66,7 @@ static void get_cstates(char *path, fwts_cstates *state)
 		return;
 
 	while ((entry = readdir(dir)) != NULL) {
-		if (entry && strlen(entry->d_name)>3) {
+		if (strlen(entry->d_name) > 3) {
 			long int nr;
 			int count;
 
@@ -255,6 +255,6 @@ static fwts_framework_ops cstates_ops = {
 	.minor_tests = cstates_tests
 };
 
-FWTS_REGISTER("cstates", &cstates_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("cstates", &cstates_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
