@@ -28,38 +28,21 @@
 
 #include "fwts_acpi_object_eval.h"
 
-#define SBBR_DBG2_PORT_SERIAL     0x8000
-#define SBBR_DBG2_ARM_SBSA_UART   0x000E
-#define SBBR_DBG2_ARM_PL011_UART  0x0003
+#define SBBR_DBG2_PORT_SERIAL          0x8000
+#define SBBR_DBG2_FULLY_16550_COMPAT   0x0000
+#define SBBR_DBG2_16550_SUBSET_COMPAT  0x0001
+#define SBBR_DBG2_ARM_PL011_UART       0x0003
+#define SBBR_DBG2_ARM_SBSA_UART        0x000E
+#define SBBR_DBG2_16550_COMPAT_GAS     0x0012
 
 static fwts_acpi_table_info *table;
-
-static int dbg2_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "DBG2", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		if (fw->flags & FWTS_FLAG_TEST_SBBR) {
-			fwts_log_error(fw,
-				"ACPI DBG2 table does not exist");
-			return FWTS_ERROR;
-		} else {
-			fwts_log_error(fw,
-				"ACPI DBG2 table does not exist, skipping test");
-			return FWTS_SKIP;
-		}
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(DBG2, &table)
 
 static int dbg2_test2(fwts_framework *fw)
 {
 	uint32_t i;
 
-	if (!(fw->flags & FWTS_FLAG_TEST_SBBR))
+	if (!(fw->flags & FWTS_FLAG_SBBR))
 		return FWTS_SKIP;
 
 	fwts_acpi_table_dbg2 *dbg2 = (fwts_acpi_table_dbg2 *)table->data;
@@ -73,11 +56,14 @@ static int dbg2_test2(fwts_framework *fw)
 		if (((uint8_t*)info + info->length) >= ((uint8_t*)table + table->length))
 			break;
 		if (info->port_type == SBBR_DBG2_PORT_SERIAL &&
-		   (info->port_subtype == SBBR_DBG2_ARM_SBSA_UART ||
-		    info->port_subtype == SBBR_DBG2_ARM_PL011_UART)) {
+		   (info->port_subtype == SBBR_DBG2_FULLY_16550_COMPAT ||
+		    info->port_subtype == SBBR_DBG2_16550_SUBSET_COMPAT ||
+		    info->port_subtype == SBBR_DBG2_ARM_PL011_UART ||
+		    info->port_subtype == SBBR_DBG2_ARM_SBSA_UART ||
+		    info->port_subtype == SBBR_DBG2_16550_COMPAT_GAS)) {
 			fwts_passed(fw,
 				"DBG2 provides a standard serial debug "
-				"port and describes ARM SBSA Generic UART");
+				"port and describes ARM BSA compliant UART");
 			return FWTS_OK;
 		}
 
@@ -148,7 +134,7 @@ static int dbg2_test1(fwts_framework *fw)
 	size_t total_size;
 
 	/* Enough length for the initial dbg2 header? */
-	if (!fwts_acpi_table_length_check(fw, "DBG2", table->length, sizeof(fwts_acpi_table_dbg2))) {
+	if (!fwts_acpi_table_length(fw, "DBG2", table->length, sizeof(fwts_acpi_table_dbg2))) {
 		passed = false;
 		goto done;
 	}
@@ -208,6 +194,9 @@ static int dbg2_test1(fwts_framework *fw)
 			case 0x0010:
 				subport = "BCM2835";
 				break;
+			case 0x0012:
+				subport = "16550-compatible with parameters in GAS";
+				break;
 			default:
 				break;
 			}
@@ -260,7 +249,7 @@ static int dbg2_test1(fwts_framework *fw)
 		fwts_log_info_simp_int(fw, "  Address Size Offset:      ", info->address_size_offset);
 		fwts_log_nl(fw);
 
-		fwts_acpi_fixed_value_check(fw, LOG_LEVEL_HIGH, "DBG2", "Info Structure Revision", info->revision, 0, &passed);
+		fwts_acpi_fixed_value(fw, LOG_LEVEL_HIGH, "DBG2", "Info Structure Revision", info->revision, 0, &passed);
 
 		if (port == NULL) {
 			passed = false;
@@ -279,7 +268,7 @@ static int dbg2_test1(fwts_framework *fw)
 				info->port_subtype);
 		}
 
-		fwts_acpi_reserved_zero_check("DBG2", "Info Structure Reserved", info->reserved, &passed);
+		fwts_acpi_reserved_zero("DBG2", "Info Structure Reserved", info->reserved, &passed);
 
 		length_ok = true;
 		dbg2_check_offset(fw, table->length, offset + info->length,
@@ -379,16 +368,16 @@ done:
 
 static fwts_framework_minor_test dbg2_tests[] = {
 	{ dbg2_test1, "DBG2 (Debug Port Table 2) test." },
-	{ dbg2_test2, "DBG2 ARM SBSA Generic UART test," },
+	{ dbg2_test2, "DBG2 ARM BSA compliant UART test," },
 	{ NULL, NULL }
 };
 
 static fwts_framework_ops dbg2_ops = {
 	.description = "DBG2 (Debug Port Table 2) test.",
-	.init        = dbg2_init,
+	.init        = DBG2_init,
 	.minor_tests = dbg2_tests
 };
 
-FWTS_REGISTER("dbg2", &dbg2_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI | FWTS_FLAG_TEST_SBBR)
+FWTS_REGISTER("dbg2", &dbg2_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI | FWTS_FLAG_SBBR)
 
 #endif
