@@ -44,7 +44,7 @@ static int erst_test1(fwts_framework *fw)
 	fwts_log_info_simp_int(fw, "  Reserved:                 ", erst->reserved);
 	fwts_log_info_simp_int(fw, "  Instruction Entry Count:  ", erst->instruction_entry_count);
 
-	fwts_acpi_reserved_zero_check("ERST", "Reserved", erst->reserved, &passed);
+	fwts_acpi_reserved_zero("ERST", "Reserved", erst->reserved, &passed);
 
 	if (erst->serialization_header_size > table->length) {
 		passed = false;
@@ -173,6 +173,6 @@ static fwts_framework_ops erst_ops = {
 	.minor_tests = erst_tests
 };
 
-FWTS_REGISTER("erst", &erst_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("erst", &erst_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
