@@ -76,9 +76,8 @@ static int fadt_init(fwts_framework *fw)
 	}
 
 	/*
-	 * Some tests require data from the FACS, also, which is
-	 * required (5.2.10) is we are not in reduced hardware
-	 * mode
+	 * Some tests require data from the FACS (5.2.10), which
+	 * requires that we are not in hardware-reduced mode
 	 */
 	if (!fwts_acpi_is_reduced_hardware(fw)) {
 		if (fwts_acpi_find_table(fw, "FACS", 0, &table) != FWTS_OK) {
@@ -197,15 +196,12 @@ static int fadt_checksum(fwts_framework *fw)
 
 static int fadt_revision(fwts_framework *fw)
 {
-	const uint8_t LATEST_MAJOR = 6;
-	const uint8_t LATEST_MINOR = 3;
+	const uint8_t LATEST_MAJOR = (FWTS_ACPI_VERSION_NOW & 0xF00) >> 8;
+	const uint8_t LATEST_MINOR = (FWTS_ACPI_VERSION_NOW & 0xFF) >> 4;
 	uint8_t major;
 	uint8_t minor;
 
-	major = fadt->header.revision;
-	minor = 0;
-	if (major >= 5 && fadt->header.length >= 268)
-		minor = fadt->minor_version;   /* field added ACPI 5.1 */
+	fwts_get_fadt_version(fw, &major, &minor);
 
 	fwts_log_info(fw, "FADT revision: %" PRIu8 ".%" PRIu8, major, minor);
 	fwts_log_info(fw, "FADT table length: %" PRIu32, fadt->header.length);
@@ -1855,6 +1851,5 @@ static fwts_framework_ops fadt_ops = {
 };
 
 FWTS_REGISTER("fadt", &fadt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH |
-	      FWTS_FLAG_ROOT_PRIV | FWTS_FLAG_TEST_ACPI |
-	      FWTS_FLAG_TEST_COMPLIANCE_ACPI)
+	      FWTS_FLAG_ROOT_PRIV | FWTS_FLAG_ACPI | FWTS_FLAG_COMPLIANCE_ACPI)
 #endif
