@@ -27,24 +27,7 @@
 #include <string.h>
 
 static fwts_acpi_table_info *table;
-
-static int gtdt_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "GTDT", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		if (fw->flags & FWTS_FLAG_TEST_SBBR) {
-			fwts_log_error(fw, "ACPI GTDT table does not exist");
-			return FWTS_ERROR;
-		} else {
-			fwts_log_error(fw, "ACPI GTDT table does not exist, skipping test");
-			return FWTS_SKIP;
-		}
-	}
-	return FWTS_OK;
-}
+acpi_table_init(GTDT, &table)
 
 /*
  *  GTDT  Generic Timer Description Table
@@ -74,7 +57,7 @@ static int gtdt_test1(fwts_framework *fw)
 			"If not provided, this field must be 0xFFFFFFFFFFFFFFFF");
 	}
 
-	fwts_acpi_reserved_bits_check("GTDT", "Flags", gtdt->virtual_timer_flags, 3, 31, &passed);
+	fwts_acpi_reserved_bits("GTDT", "Flags", gtdt->virtual_timer_flags, 3, 31, &passed);
 
 	ptr = (uint8_t *)table->data + gtdt->platform_timer_offset;
 	n = gtdt->platform_timer_count;
@@ -188,13 +171,13 @@ static int gtdt_test1(fwts_framework *fw)
 				}
 
 				snprintf(field, sizeof(field), "block %" PRIu32 " physical timer flags", i);
-				fwts_acpi_reserved_bits_check("GTDT", field, block_timer->phys_timer_flags, 2, 31, &passed);
+				fwts_acpi_reserved_bits("GTDT", field, block_timer->phys_timer_flags, 2, 31, &passed);
 
 				snprintf(field, sizeof(field), "block %" PRIu32 " virtual timer flags", i);
-				fwts_acpi_reserved_bits_check("GTDT", field, block_timer->virt_timer_flags, 2, 31, &passed);
+				fwts_acpi_reserved_bits("GTDT", field, block_timer->virt_timer_flags, 2, 31, &passed);
 
 				snprintf(field, sizeof(field), "block %" PRIu32 " common flags", i);
-				fwts_acpi_reserved_bits_check("GTDT", field, block_timer->common_flags, 2, 31, &passed);
+				fwts_acpi_reserved_bits("GTDT", field, block_timer->common_flags, 2, 31, &passed);
 			}
 			ptr += block->length;
 			break;
@@ -242,7 +225,7 @@ static int gtdt_test1(fwts_framework *fw)
 			}
 
 			snprintf(field, sizeof(field), "SBSA generic watchdog timer %" PRIu32 " flags", i);
-			fwts_acpi_reserved_bits_check("GTDT", field, watchdog->watchdog_timer_flags, 3, 31, &passed);
+			fwts_acpi_reserved_bits("GTDT", field, watchdog->watchdog_timer_flags, 3, 31, &passed);
 
 			ptr += watchdog->length;
 			break;
@@ -250,7 +233,7 @@ static int gtdt_test1(fwts_framework *fw)
 			passed = false;
 			fwts_failed(fw, LOG_LEVEL_HIGH,
 				"GTDTInvalidType",
-				"GTDT platform timer strucuture %" PRIu32
+				"GTDT platform timer structure %" PRIu32
 				" has an invalid type: 0x%" PRIx8, i, *ptr);
 			/* Can't determine field length, so end of parsing */
 			goto done;
@@ -272,10 +255,10 @@ static fwts_framework_minor_test gtdt_tests[] = {
 
 static fwts_framework_ops gtdt_ops = {
 	.description = "GTDT Generic Timer Description Table test.",
-	.init        = gtdt_init,
+	.init        = GTDT_init,
 	.minor_tests = gtdt_tests
 };
 
-FWTS_REGISTER("gtdt", &gtdt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI | FWTS_FLAG_TEST_SBBR)
+FWTS_REGISTER("gtdt", &gtdt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI | FWTS_FLAG_SBBR)
 
 #endif
