@@ -80,8 +80,8 @@ static void lpit_check_type_0(
 	}
 	fwts_log_nl(fw);
 
-	fwts_acpi_reserved_zero_check("LPIT", "Native C-state based LPI structure reserved", lpi->reserved, passed);
-	fwts_acpi_reserved_bits_check("LPIT", "LPI structure flags", lpi->flags, 2, 31, passed);
+	fwts_acpi_reserved_zero("LPIT", "Native C-state based LPI structure reserved", lpi->reserved, passed);
+	fwts_acpi_reserved_bits("LPIT", "LPI structure flags", lpi->flags, 2, 31, passed);
 
 	/* 2.2.1.2, if FFH, then it is a MSR, check GAS fields */
 	if (((lpi->flags & 2) == 0) &&
@@ -221,6 +221,6 @@ static fwts_framework_ops lpit_ops = {
 	.minor_tests = lpit_tests
 };
 
-FWTS_REGISTER("lpit", &lpit_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("lpit", &lpit_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
