@@ -126,7 +126,7 @@ static int nfit_test1(fwts_framework *fw)
 	fwts_log_info_simp_int(fw, "  Reserved:                 ", nfit->reserved);
 	fwts_log_nl(fw);
 
-	fwts_acpi_reserved_zero_check("NFIT", "Reserved", nfit->reserved, &passed);
+	fwts_acpi_reserved_zero("NFIT", "Reserved", nfit->reserved, &passed);
 
 	offset = sizeof(fwts_acpi_table_nfit);
 	entry = (fwts_acpi_table_nfit_struct_header *)(nfit_table->data + offset);
@@ -138,23 +138,20 @@ static int nfit_test1(fwts_framework *fw)
 		fwts_log_info_simp_int(fw, "    Type:                                   ", entry->type);
 		fwts_log_info_simp_int(fw, "    Length:                                 ", entry->length);
 
-		if (entry->length == 0) {
+		if (fwts_acpi_structure_length_zero(fw, "NFIT", entry->length, offset)) {
 			passed = false;
-			fwts_failed(fw, LOG_LEVEL_HIGH, "NFITLengthZero",
-				    "NFIT Subtable (offset 0x%4.4" PRIx32 ") "
-				    "length cannot be 0", offset);
 			break;
 		}
 
-		if (entry->type == FWTS_ACPI_NFIT_TYPE_SYSTEM_ADDRESS) {
+		if (entry->type == FWTS_NFIT_TYPE_SYSTEM_ADDRESS) {
 			fwts_acpi_table_nfit_system_memory *nfit_struct = (fwts_acpi_table_nfit_system_memory *) entry;
 			char guid_str[37];
 			bool guid_skip = false;
 			size_t i;
 
 			bool ret = check_length(fw, entry->length,
-					FWTS_ACPI_NFIT_MINLEN_SYSTEM_ADDRESS,
-					FWTS_ACPI_NFIT_NAME_SYSTEM_ADDRESS);
+					FWTS_NFIT_MINLEN_SYSTEM_ADDRESS,
+					FWTS_NFIT_NAME_SYSTEM_ADDRESS);
 			if (!ret) {
 				passed = false;
 				break;
@@ -232,7 +229,7 @@ static int nfit_test1(fwts_framework *fw)
 				}
 			}
 
-			fwts_acpi_reserved_bits_check("NFIT", "Flags", nfit_struct->flags, 3, 15, &passed);
+			fwts_acpi_reserved_bits("NFIT", "Flags", nfit_struct->flags, 3, 15, &passed);
 
 			if (nfit_struct->reserved != 0)
 				reserved_passed = nfit_struct->reserved;
@@ -247,12 +244,12 @@ static int nfit_test1(fwts_framework *fw)
 					"0x%16.16" PRIx64 " instead", nfit_struct->memory_mapping);
 			}
 
-		} else if (entry->type == FWTS_ACPI_NFIT_TYPE_MEMORY_MAP) {
+		} else if (entry->type == FWTS_NFIT_TYPE_MEMORY_MAP) {
 			fwts_acpi_table_nfit_memory_map *nfit_struct = (fwts_acpi_table_nfit_memory_map *) entry;
 
 			bool ret = check_length(fw, entry->length,
-					FWTS_ACPI_NFIT_MINLEN_MEMORY_MAP,
-					FWTS_ACPI_NFIT_NAME_MEMORY_MAP);
+					FWTS_NFIT_MINLEN_MEMORY_MAP,
+					FWTS_NFIT_NAME_MEMORY_MAP);
 			if (!ret) {
 				passed = false;
 				break;
@@ -271,18 +268,18 @@ static int nfit_test1(fwts_framework *fw)
 			fwts_log_info_simp_int(fw, "    NVDIMM State Flags:                     ", nfit_struct->flags);
 			fwts_log_info_simp_int(fw, "    Reserved:                               ", nfit_struct->reserved);
 
-			fwts_acpi_reserved_bits_check("NFIT", "NVDIMM State Flags", nfit_struct->flags, 7, 15, &passed);
+			fwts_acpi_reserved_bits("NFIT", "NVDIMM State Flags", nfit_struct->flags, 7, 15, &passed);
 
 			if (nfit_struct->reserved != 0)
 				reserved_passed = nfit_struct->reserved;
 
-		} else if (entry->type == FWTS_ACPI_NFIT_TYPE_INTERLEAVE) {
+		} else if (entry->type == FWTS_NFIT_TYPE_INTERLEAVE) {
 			fwts_acpi_table_nfit_interleave *nfit_struct = (fwts_acpi_table_nfit_interleave *) entry;
 			uint32_t i;
 
 			bool ret = check_length(fw, entry->length,
-					FWTS_ACPI_NFIT_MINLEN_INTERLEAVE,
-					FWTS_ACPI_NFIT_NAME_INTERLEAVE);
+					FWTS_NFIT_MINLEN_INTERLEAVE,
+					FWTS_NFIT_NAME_INTERLEAVE);
 			if (!ret) {
 				passed = false;
 				break;
@@ -294,9 +291,9 @@ static int nfit_test1(fwts_framework *fw)
 			fwts_log_info_simp_int(fw, "    Line Size:                              ", nfit_struct->line_size);
 
 			ret = check_length(fw, entry->length,
-					FWTS_ACPI_NFIT_MINLEN_INTERLEAVE +
+					FWTS_NFIT_MINLEN_INTERLEAVE +
 						nfit_struct->line_count * sizeof nfit_struct->line_offset[0],
-					FWTS_ACPI_NFIT_NAME_INTERLEAVE);
+					FWTS_NFIT_NAME_INTERLEAVE);
 			if (!ret) {
 				passed = false;
 				break;
@@ -318,12 +315,12 @@ static int nfit_test1(fwts_framework *fw)
 					"NFIT Number of Lines must not be zero");
 			}
 
-		} else if (entry->type == FWTS_ACPI_NFIT_TYPE_SMBIOS) {
+		} else if (entry->type == FWTS_NFIT_TYPE_SMBIOS) {
 			fwts_acpi_table_nfit_smbios *nfit_struct = (fwts_acpi_table_nfit_smbios *) entry;
 
 			bool ret = check_length(fw, entry->length,
-					FWTS_ACPI_NFIT_MINLEN_SMBIOS,
-					FWTS_ACPI_NFIT_NAME_SMBIOS);
+					FWTS_NFIT_MINLEN_SMBIOS,
+					FWTS_NFIT_NAME_SMBIOS);
 			if (!ret) {
 				passed = false;
 				break;
@@ -340,11 +337,11 @@ static int nfit_test1(fwts_framework *fw)
 			if (!ret)
 				passed = false;
 
-		} else if (entry->type == FWTS_ACPI_NFIT_TYPE_CONTROL_REGION) {
+		} else if (entry->type == FWTS_NFIT_TYPE_CONTROL_REGION) {
 			fwts_acpi_table_nfit_control_range *nfit_struct = (fwts_acpi_table_nfit_control_range *) entry;
 			bool ret = check_length(fw, entry->length,
-					FWTS_ACPI_NFIT_MINLEN_CONTROL_REGION,
-					FWTS_ACPI_NFIT_NAME_CONTROL_REGION);
+					FWTS_NFIT_MINLEN_CONTROL_REGION,
+					FWTS_NFIT_NAME_CONTROL_REGION);
 			if (!ret) {
 				passed = false;
 				break;
@@ -383,7 +380,7 @@ static int nfit_test1(fwts_framework *fw)
 			if (nfit_struct->reserved != 0)
 				reserved_passed = nfit_struct->reserved;
 
-			fwts_acpi_reserved_bits_check("NFIT", "Valid", nfit_struct->valid_fields, 1, 7, &passed);
+			fwts_acpi_reserved_bits("NFIT", "Valid", nfit_struct->valid_fields, 1, 7, &passed);
 
 			if (entry->length >= sizeof(*nfit_struct)) {
 				uint64_t reserved1;
@@ -406,16 +403,16 @@ static int nfit_test1(fwts_framework *fw)
 				fwts_log_info_simp_int(fw, "    NVDIMM Control Region Flag:             ", nfit_struct->flags);
 				fwts_log_info_simp_int(fw, "    Reserved:                               ", reserved1);
 
-				fwts_acpi_reserved_bits_check("NFIT", "NVDIMM Control Region Flags", nfit_struct->flags, 1, 15, &passed);
+				fwts_acpi_reserved_bits("NFIT", "NVDIMM Control Region Flags", nfit_struct->flags, 1, 15, &passed);
 				fwts_log_info_simp_int(fw, "    NVDIMM Control Region Structure Index:  ", nfit_struct->region_index);
 			}
 
-		} else if (entry->type == FWTS_ACPI_NFIT_TYPE_DATA_REGION) {
+		} else if (entry->type == FWTS_NFIT_TYPE_DATA_REGION) {
 			fwts_acpi_table_nfit_data_range *nfit_struct = (fwts_acpi_table_nfit_data_range *) entry;
 
 			bool ret = check_length(fw, entry->length,
-					FWTS_ACPI_NFIT_MINLEN_DATA_REGION,
-					FWTS_ACPI_NFIT_NAME_DATA_REGION);
+					FWTS_NFIT_MINLEN_DATA_REGION,
+					FWTS_NFIT_NAME_DATA_REGION);
 			if (!ret) {
 				passed = false;
 				break;
@@ -435,14 +432,14 @@ static int nfit_test1(fwts_framework *fw)
 					"NFIT NVDIMM Control Region Structure Index must not be zero");
 			}
 
-		} else if (entry->type == FWTS_ACPI_NFIT_TYPE_FLUSH_ADDRESS) {
+		} else if (entry->type == FWTS_NFIT_TYPE_FLUSH_ADDRESS) {
 			fwts_acpi_table_nfit_flush_addr *nfit_struct = (fwts_acpi_table_nfit_flush_addr *) entry;
 			uint64_t reserved;
 			uint16_t i;
 
 			bool ret = check_length(fw, entry->length,
-					FWTS_ACPI_NFIT_MINLEN_FLUSH_ADDRESS,
-					FWTS_ACPI_NFIT_NAME_FLUSH_ADDRESS);
+					FWTS_NFIT_MINLEN_FLUSH_ADDRESS,
+					FWTS_NFIT_NAME_FLUSH_ADDRESS);
 			if (!ret) {
 				passed = false;
 				break;
@@ -457,9 +454,9 @@ static int nfit_test1(fwts_framework *fw)
 			fwts_log_info_simp_int(fw, "    Reserved:                               ", reserved);
 
 			ret = check_length(fw, entry->length,
-					FWTS_ACPI_NFIT_MINLEN_FLUSH_ADDRESS +
+					FWTS_NFIT_MINLEN_FLUSH_ADDRESS +
 						nfit_struct->hint_count * sizeof nfit_struct->hint_address[0],
-					FWTS_ACPI_NFIT_NAME_FLUSH_ADDRESS);
+					FWTS_NFIT_NAME_FLUSH_ADDRESS);
 			if (!ret) {
 				passed = false;
 				break;
@@ -471,13 +468,13 @@ static int nfit_test1(fwts_framework *fw)
 			if (reserved != 0)
 				reserved_passed = reserved;
 
-		} else if (entry->type == FWTS_ACPI_NFIT_TYPE_PLATFORM_CAPABILITY) {
+		} else if (entry->type == FWTS_NFIT_TYPE_PLATFORM_CAPABILITY) {
 			fwts_acpi_table_nfit_platform_cap *nfit_struct = (fwts_acpi_table_nfit_platform_cap *) entry;
 			uint32_t reserved1;
 
 			bool ret = check_length(fw, entry->length,
-					FWTS_ACPI_NFIT_MINLEN_PLATFORM_CAPABILITY,
-					FWTS_ACPI_NFIT_NAME_PLATFORM_CAPABILITY);
+					FWTS_NFIT_MINLEN_PLATFORM_CAPABILITY,
+					FWTS_NFIT_NAME_PLATFORM_CAPABILITY);
 			if (!ret) {
 				passed = false;
 				break;
@@ -491,8 +488,8 @@ static int nfit_test1(fwts_framework *fw)
 			fwts_log_info_simp_int(fw, "    Capabilities:                           ", nfit_struct->cap);
 			fwts_log_info_simp_int(fw, "    Reserved2:                              ", nfit_struct->reserved2);
 
-			fwts_acpi_reserved_zero_check("NFIT", "Reserved1", reserved1, &passed);
-			fwts_acpi_reserved_bits_check("NFIT", "Capabilities", nfit_struct->cap, 3, 31, &passed);
+			fwts_acpi_reserved_zero("NFIT", "Reserved1", reserved1, &passed);
+			fwts_acpi_reserved_bits("NFIT", "Capabilities", nfit_struct->cap, 3, 31, &passed);
 
 			if ((nfit_struct->cap & 0x1) && !(nfit_struct->cap & 0x2)) {
 				passed = false;
@@ -506,17 +503,19 @@ static int nfit_test1(fwts_framework *fw)
 				reserved_passed = nfit_struct->reserved2;
 
 		} else {
-			passed = false;
-			fwts_failed(fw, LOG_LEVEL_HIGH,
-				"NFITBadSubType",
-				"NFIT Structure supports type 0..%" PRId8 ", got "
-				"0x%4.4" PRIx16 " instead", FWTS_ACPI_NFIT_TYPE_RESERVED - 1,
-				entry->type);
+			fwts_acpi_reserved_type(fw, "NFIT", entry->type, 0, FWTS_NFIT_TYPE_RESERVED - 1, &passed);
+			break;
 		}
 
-		fwts_acpi_reserved_zero_check("NFIT", "Reserved", reserved_passed, &passed);
+		fwts_acpi_reserved_zero("NFIT", "Reserved", reserved_passed, &passed);
 		fwts_log_nl(fw);
+
 		offset += entry->length;
+		if (fwts_acpi_structure_range(fw, "NFIT", nfit_table->length, offset)) {
+			passed = false;
+			break;
+		}
+
 		entry = (fwts_acpi_table_nfit_struct_header *)(nfit_table->data + offset);
 	}
 
@@ -538,6 +537,6 @@ static fwts_framework_ops nfit_ops = {
 	.minor_tests = nfit_tests
 };
 
-FWTS_REGISTER("nfit", &nfit_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("nfit", &nfit_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
