@@ -26,7 +26,11 @@
 static fwts_acpi_table_info *table;
 acpi_table_init(PCCT, &table)
 
-static bool subspace_length_equal(fwts_framework *fw, uint8_t type, uint8_t type_size, uint8_t length)
+static bool subspace_length_equal(
+	fwts_framework *fw,
+	const uint8_t type,
+	const uint8_t type_size,
+	const uint8_t length)
 {
 	if (type_size != length) {
 		fwts_failed(fw, LOG_LEVEL_HIGH,
@@ -39,7 +43,11 @@ static bool subspace_length_equal(fwts_framework *fw, uint8_t type, uint8_t type
 	return true;
 }
 
-static void gas_messages(fwts_framework *fw, uint8_t type, fwts_acpi_gas *gas, bool *passed)
+static void gas_messages(
+	fwts_framework *fw,
+	const uint8_t type,
+	const fwts_acpi_gas *gas,
+	bool *passed)
 {
 	char label[20];
 
@@ -50,13 +58,17 @@ static void gas_messages(fwts_framework *fw, uint8_t type, fwts_acpi_gas *gas, b
 	fwts_log_info_simp_int(fw, "      Address                    ", gas->address);
 
 	snprintf(label, sizeof(label), "Subspace Type % " PRId8, type);
-	fwts_acpi_space_id_check(fw, "PCCT", label, passed, gas->address_space_id, 3,
-				 FWTS_GAS_ADDR_SPACE_ID_SYSTEM_MEMORY,
-				 FWTS_GAS_ADDR_SPACE_ID_SYSTEM_IO,
-				 FWTS_GAS_ADDR_SPACE_ID_FFH);
+	fwts_acpi_space_id(fw, "PCCT", label, passed, gas->address_space_id, 3,
+			   FWTS_GAS_ADDR_SPACE_ID_SYSTEM_MEMORY,
+			   FWTS_GAS_ADDR_SPACE_ID_SYSTEM_IO,
+			   FWTS_GAS_ADDR_SPACE_ID_FFH);
 }
 
-static void gas_messages2(fwts_framework *fw, uint8_t type, fwts_acpi_gas *gas, bool *passed)
+static void gas_messages2(
+	fwts_framework *fw,
+	const uint8_t type,
+	const fwts_acpi_gas *gas,
+	bool *passed)
 {
 	char label[20];
 
@@ -67,11 +79,16 @@ static void gas_messages2(fwts_framework *fw, uint8_t type, fwts_acpi_gas *gas,
 	fwts_log_info_simp_int(fw, "      Address                    ", gas->address);
 
 	snprintf(label, sizeof(label), "Subspace Type % " PRId8, type);
-	fwts_acpi_space_id_check(fw, "PCCT", label, passed, gas->address_space_id, 2,
-				 FWTS_GAS_ADDR_SPACE_ID_SYSTEM_MEMORY, FWTS_GAS_ADDR_SPACE_ID_SYSTEM_IO);
+	fwts_acpi_space_id(fw, "PCCT", label, passed, gas->address_space_id, 2,
+			   FWTS_GAS_ADDR_SPACE_ID_SYSTEM_MEMORY, FWTS_GAS_ADDR_SPACE_ID_SYSTEM_IO);
 }
 
-static void memory_length(fwts_framework *fw, uint8_t type, uint64_t memory_range, uint64_t min_length, bool *passed)
+static void memory_length(
+	fwts_framework *fw,
+	const uint8_t type,
+	const uint64_t memory_range,
+	const uint64_t min_length,
+	bool *passed)
 {
 	switch (type) {
 	case 0 ... 2:
@@ -97,7 +114,10 @@ static void memory_length(fwts_framework *fw, uint8_t type, uint64_t memory_rang
 	}
 }
 
-static void generic_comm_test(fwts_framework *fw, fwts_acpi_table_pcct_subspace_type_0 *entry, bool *passed)
+static void generic_comm_test(
+	fwts_framework *fw,
+	const fwts_acpi_table_pcct_subspace_type_0 *entry,
+	bool *passed)
 {
 	uint64_t reserved;
 
@@ -117,7 +137,10 @@ static void generic_comm_test(fwts_framework *fw, fwts_acpi_table_pcct_subspace_
 	fwts_log_info_simp_int(fw, "    Min Request Turnaround Time: ", entry->min_request_turnaround_time);
 }
 
-static void hw_reduced_comm_test_type1(fwts_framework *fw, fwts_acpi_table_pcct_subspace_type_1 *entry, bool *passed)
+static void hw_reduced_comm_test_type1(
+	fwts_framework *fw,
+	const fwts_acpi_table_pcct_subspace_type_1 *entry,
+	bool *passed)
 {
 	fwts_log_info_simp_int(fw, "    Platform Interrupt:          ", entry->platform_interrupt);
 	fwts_log_info_simp_int(fw, "    Platform Interrupt Flags:    ", entry->platform_interrupt_flags);
@@ -132,10 +155,13 @@ static void hw_reduced_comm_test_type1(fwts_framework *fw, fwts_acpi_table_pcct_
 	fwts_log_info_simp_int(fw, "    Max Periodic Access Rate:    ", entry->max_periodic_access_rate);
 	fwts_log_info_simp_int(fw, "    Min Request Turnaround Time: ", entry->min_request_turnaround_time);
 
-	fwts_acpi_reserved_bits_check("PCCT", "Platform Interrupt Flags", entry->platform_interrupt_flags, 2, 7, passed);
+	fwts_acpi_reserved_bits("PCCT", "Platform Interrupt Flags", entry->platform_interrupt_flags, 2, 7, passed);
 }
 
-static void hw_reduced_comm_test_type2(fwts_framework *fw, fwts_acpi_table_pcct_subspace_type_2 *entry, bool *passed)
+static void hw_reduced_comm_test_type2(
+	fwts_framework *fw,
+	const fwts_acpi_table_pcct_subspace_type_2 *entry,
+	bool *passed)
 {
 	fwts_log_info_simp_int(fw, "    Platform Interrupt:          ", entry->platform_interrupt);
 	fwts_log_info_simp_int(fw, "    Platform Interrupt Flags:    ", entry->platform_interrupt_flags);
@@ -154,10 +180,13 @@ static void hw_reduced_comm_test_type2(fwts_framework *fw, fwts_acpi_table_pcct_
 	fwts_log_info_simp_int(fw, "    Platform Ack Preserve:       ", entry->platform_ack_preserve);
 	fwts_log_info_simp_int(fw, "    Platform Ack Write:          ", entry->platform_ack_write);
 
-	fwts_acpi_reserved_bits_check("PCCT", "Platform Interrupt Flags", entry->platform_interrupt_flags, 2, 7, passed);
+	fwts_acpi_reserved_bits("PCCT", "Platform Interrupt Flags", entry->platform_interrupt_flags, 2, 7, passed);
 }
 
-static void extended_pcc_test(fwts_framework *fw, fwts_acpi_table_pcct_subspace_type_3_4 *entry, bool *passed)
+static void extended_pcc_test(
+	fwts_framework *fw,
+	const fwts_acpi_table_pcct_subspace_type_3_4 *entry,
+	bool *passed)
 {
 	fwts_log_info_simp_int(fw, "    Platform Interrupt:          ", entry->platform_interrupt);
 	fwts_log_info_simp_int(fw, "    Platform Interrupt Flags:    ", entry->platform_interrupt_flags);
@@ -187,10 +216,13 @@ static void extended_pcc_test(fwts_framework *fw, fwts_acpi_table_pcct_subspace_
 	gas_messages(fw, entry->header.type, &entry->error_status_register, passed);
 	fwts_log_info_simp_int(fw, "    Error Status Mask:           ", entry->error_status_mask);
 
-	fwts_acpi_reserved_bits_check("PCCT", "Platform Interrupt Flags", entry->platform_interrupt_flags, 2, 7, passed);
+	fwts_acpi_reserved_bits("PCCT", "Platform Interrupt Flags", entry->platform_interrupt_flags, 2, 7, passed);
 }
 
-static void hw_registers_based_comm_test(fwts_framework *fw, fwts_acpi_table_pcct_subspace_type_5 *entry, bool *passed)
+static void hw_registers_based_comm_test(
+	fwts_framework *fw,
+	const fwts_acpi_table_pcct_subspace_type_5 *entry,
+	bool *passed)
 {
 	fwts_log_info_simp_int(fw, "    Version:                     ", entry->version);
 	fwts_log_info_simp_int(fw, "    Base Address:                ", entry->base_address);
@@ -221,8 +253,8 @@ static int pcct_test1(fwts_framework *fw)
 	fwts_log_info_simp_int(fw, "  Reserved:  ", pcct->reserved);
 	fwts_log_nl(fw);
 
-	fwts_acpi_reserved_bits_check("PCCT", "Flags", pcct->flags, 1, 31, &passed);
-	fwts_acpi_reserved_zero_check("PCCT", "Reserved", pcct->reserved, &passed);
+	fwts_acpi_reserved_bits("PCCT", "Flags", pcct->flags, 1, 31, &passed);
+	fwts_acpi_reserved_zero("PCCT", "Reserved", pcct->reserved, &passed);
 
 	offset = sizeof(fwts_acpi_table_pcct);
 	pcct_sub = (fwts_acpi_table_pcct_subspace_header *) (table->data + offset);
@@ -333,6 +365,6 @@ static fwts_framework_ops pcct_ops = {
 	.minor_tests = pcct_tests
 };
 
-FWTS_REGISTER("pcct", &pcct_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("pcct", &pcct_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
