@@ -26,7 +26,11 @@
 static fwts_acpi_table_info *table;
 acpi_table_init(PPTT, &table)
 
-static void pptt_processor_test(fwts_framework *fw, const fwts_acpi_table_pptt_processor *entry, uint8_t rev, bool *passed)
+static void pptt_processor_test(
+	fwts_framework *fw,
+	const fwts_acpi_table_pptt_processor *entry,
+	const uint8_t rev,
+	bool *passed)
 {
 	fwts_log_info_verbatim(fw, "  Processor hierarchy node structure (Type 0):");
 	fwts_log_info_simp_int(fw, "    Type:                           ", entry->header.type);
@@ -51,16 +55,20 @@ static void pptt_processor_test(fwts_framework *fw, const fwts_acpi_table_pptt_p
 			entry->number_priv_resources);
 	}
 
-	fwts_acpi_reserved_zero_check("PPTT", "Reserved", entry->reserved, passed);
+	fwts_acpi_reserved_zero("PPTT", "Reserved", entry->reserved, passed);
 
 	if (rev == 1)
-		fwts_acpi_reserved_bits_check("PPTT", "Flags", entry->flags, 2, 31, passed);
-	else if (rev == 2)
-		fwts_acpi_reserved_bits_check("PPTT", "Flags", entry->flags, 5, 31, passed);
+		fwts_acpi_reserved_bits("PPTT", "Flags", entry->flags, 2, 31, passed);
+	else
+		fwts_acpi_reserved_bits("PPTT", "Flags", entry->flags, 5, 31, passed);
 
 }
 
-static void pptt_cache_test(fwts_framework *fw, const fwts_acpi_table_pptt_cache *entry, bool *passed)
+static void pptt_cache_test(
+	fwts_framework *fw,
+	const fwts_acpi_table_pptt_cache *entry,
+	const uint8_t rev,
+	bool *passed)
 {
 
 	fwts_log_info_verbatim(fw, "  Cache Type Structure (Type 1):");
@@ -74,13 +82,23 @@ static void pptt_cache_test(fwts_framework *fw, const fwts_acpi_table_pptt_cache
 	fwts_log_info_simp_int(fw, "    Associativity:                  ", entry->associativity);
 	fwts_log_info_simp_int(fw, "    Attributes:                     ", entry->attributes);
 	fwts_log_info_simp_int(fw, "    Line size:                      ", entry->line_size);
+	if (rev >= 3)
+		fwts_log_info_simp_int(fw, "    Cache ID:                       ", entry->cache_id);
 
-	fwts_acpi_reserved_zero_check("PPTT", "Reserved", entry->reserved, passed);
-	fwts_acpi_reserved_bits_check("PPTT", "Flags", entry->flags, 7, 31, passed);
-	fwts_acpi_reserved_bits_check("PPTT", "Attributes", entry->attributes, 5, 7, passed);
+	fwts_acpi_reserved_zero("PPTT", "Reserved", entry->reserved, passed);
+
+	if (rev == 1 || rev == 2)
+		fwts_acpi_reserved_bits("PPTT", "Flags", entry->flags, 7, 31, passed);
+	else
+		fwts_acpi_reserved_bits("PPTT", "Flags", entry->flags, 8, 31, passed);
+
+	fwts_acpi_reserved_bits("PPTT", "Attributes", entry->attributes, 5, 7, passed);
 }
 
-static void pptt_id_test(fwts_framework *fw, const fwts_acpi_table_pptt_id *entry, bool *passed)
+static void pptt_id_test(
+	fwts_framework *fw,
+	const fwts_acpi_table_pptt_id *entry,
+	bool *passed)
 {
 	char vendor_id[5];
 
@@ -98,7 +116,7 @@ static void pptt_id_test(fwts_framework *fw, const fwts_acpi_table_pptt_id *entr
 	fwts_log_info_simp_int(fw, "    MINOR_REV:                      ", entry->minor_rev);
 	fwts_log_info_simp_int(fw, "    SPIN_REV:                       ", entry->spin_rev);
 
-	fwts_acpi_reserved_zero_check("PPTT", "Reserved", entry->reserved, passed);
+	fwts_acpi_reserved_zero("PPTT", "Reserved", entry->reserved, passed);
 }
 
 static int pptt_test1(fwts_framework *fw)
@@ -116,51 +134,40 @@ static int pptt_test1(fwts_framework *fw)
 	while (offset < table->length) {
 		uint32_t type_length;
 
-		if (entry->length == 0) {
+		if (fwts_acpi_structure_length_zero(fw, "PPTT", entry->length, offset)) {
 			passed = false;
-			fwts_failed(fw, LOG_LEVEL_HIGH, "PPTTStructLengthZero",
-				    "PPTT structure (offset 0x%4.4" PRIx32 ") "
-				    "length cannot be 0", offset);
 			break;
 		}
 
-		if (entry->type == FWTS_ACPI_PPTT_PROCESSOR) {
+		if (entry->type == FWTS_PPTT_PROCESSOR) {
 			pptt_processor_test(fw, (fwts_acpi_table_pptt_processor *) entry, pptt->header.revision, &passed);
 			type_length = sizeof(fwts_acpi_table_pptt_processor) +
 				      ((fwts_acpi_table_pptt_processor *) entry)->number_priv_resources * 4;
-		} else if (entry->type == FWTS_ACPI_PPTT_CACHE) {
-			pptt_cache_test(fw, (fwts_acpi_table_pptt_cache *) entry, &passed);
+		} else if (entry->type == FWTS_PPTT_CACHE) {
+			pptt_cache_test(fw, (fwts_acpi_table_pptt_cache *) entry, pptt->header.revision, &passed);
 			type_length = sizeof(fwts_acpi_table_pptt_cache);
-		} else if (entry->type == FWTS_ACPI_PPTT_ID) {
-			fwts_log_warning(fw, "PPTT type 2 is depreciated since ACPI 6.3 Errata A.");
+			if (pptt->header.revision < 3)
+				type_length -= sizeof(((fwts_acpi_table_pptt_cache *) entry)->cache_id);
+		} else if (entry->type == FWTS_PPTT_ID) {
+			fwts_log_warning(fw, "PPTT type 2 is deprecated since ACPI 6.3 Errata A.");
 			pptt_id_test(fw, (fwts_acpi_table_pptt_id *) entry, &passed);
 			type_length = sizeof(fwts_acpi_table_pptt_id);
 		} else {
-			passed = false;
-			fwts_failed(fw, LOG_LEVEL_HIGH,
-				"PPTTBadSubtableType",
-				"PPTT must have subtable with Type 0..2, got "
-				"0x%2.2" PRIx8 " instead", entry->type);
+			fwts_acpi_reserved_type(fw, "PPTT", entry->type, 0, FWTS_PPTT_RESERVED - 1, &passed);
 			break;
 		}
 
-		if (entry->length != type_length) {
+		if (!fwts_acpi_structure_length(fw, "PPTT", entry->type, entry->length, type_length)) {
 			passed = false;
-			fwts_failed(fw, LOG_LEVEL_CRITICAL,
-				"PPTTBadSubtableLength",
-				"PPTT subtable Type 0x%2.2" PRIx8 " should have "
-				"length 0x%2.2" PRIx8 ", got 0x%2.2" PRIx8,
-				entry->type, type_length, entry->length);
 			break;
 		}
 
-		if ((offset += entry->length) > table->length) {
+		offset += entry->length;
+		if (fwts_acpi_structure_range(fw, "PPTT", table->length, offset)) {
 			passed = false;
-			fwts_failed(fw, LOG_LEVEL_CRITICAL,
-				"PPTTBadTableLength",
-				"PPTT has more subtypes than its size can handle");
 			break;
 		}
+
 		entry = (fwts_acpi_table_pptt_header *) (table->data + offset);
 		fwts_log_nl(fw);
 	}
@@ -182,6 +189,6 @@ static fwts_framework_ops pptt_ops = {
 	.minor_tests = pptt_tests
 };
 
-FWTS_REGISTER("pptt", &pptt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("pptt", &pptt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI | FWTS_FLAG_SBBR)
 
 #endif
