@@ -36,6 +36,7 @@
 #define PM_S2IDLE_SLP_S0		"/sys/kernel/debug/pmc_core/slp_s0_residency_usec"
 
 static char sleep_type[7];
+static char sleep_type_orig[7];
 
 static int  s3_multiple = 1;		/* number of s3 multiple tests to run */
 static int  s3_min_delay = 0;		/* min time between resume and next suspend */
@@ -50,6 +51,7 @@ static float s3_suspend_time = 15.0;	/* Maximum allowed suspend time */
 static float s3_resume_time = 15.0;	/* Maximum allowed resume time */
 static bool s3_hybrid = false;
 static char *s3_hook = NULL;		/* Hook to run after each S3 */
+static char *s3_sleep_type = NULL;	/* The sleep type(s3 or s2idle) */
 
 static int s3_init(fwts_framework *fw)
 {
@@ -66,6 +68,20 @@ static int s3_init(fwts_framework *fw)
 		return FWTS_ERROR;
 	}
 
+	str = fwts_get(PM_SUSPEND_PATH);
+	if (str && strstr(str, "[s2idle]")) {
+		strncpy(sleep_type_orig, "s2idle", strlen("s2idle") + 1);
+		free(str);
+	} else {
+		strncpy(sleep_type_orig, "deep", strlen("deep") + 1);
+	}
+
+	if (s3_sleep_type) {
+		fwts_log_info(fw, "Override system suspend default by '%s'\n", s3_sleep_type);
+		if (fwts_set(PM_SUSPEND_PATH, s3_sleep_type) != FWTS_OK)
+			fwts_log_error(fw, "Cannot set the sleep type to %s, test with default type.", s3_sleep_type);
+	}
+
 	str = fwts_get(PM_SUSPEND_PATH);
 	if (str && strstr(str, "[s2idle]")) {
 		strncpy(sleep_type, "s2idle", strlen("s2idle") + 1);
@@ -77,6 +93,15 @@ static int s3_init(fwts_framework *fw)
 	return FWTS_OK;
 }
 
+static int s3_deinit(fwts_framework *fw)
+{
+
+	FWTS_UNUSED(fw);
+	(void)fwts_set(PM_SUSPEND_PATH, sleep_type_orig);
+
+	return FWTS_OK;
+}
+
 /*
  *  s3_hook_exec()
  *	run a given hook script
@@ -210,16 +235,16 @@ static int wrap_pmutils_do_suspend(fwts_pm_method_vars *fwts_settings,
  *  get_s2_idle_residency()
  *	read PM_S2IDLE_SLP_S0, return 0 if it is not available
  */
-static uint32_t get_s2_idle_residency(void)
+static uint64_t get_s2_idle_residency(void)
 {
 	char *str;
-	uint32_t val;
+	uint64_t val;
 
 	str = fwts_get(PM_S2IDLE_SLP_S0);
 	if (!str)
 		return 0;
 
-	val = atoi(str);
+	val = atoll(str);
 	free(str);
 
 	return val;
@@ -230,7 +255,7 @@ static int s3_do_suspend_resume(fwts_framework *fw,
 	int *pm_errors,
 	int *hook_errors,
 	int *s2idle_errors,
-	uint32_t *s2idle_residency,
+	uint64_t *s2idle_residency,
 	int delay,
 	int percent)
 {
@@ -355,13 +380,13 @@ static int s3_do_suspend_resume(fwts_framework *fw,
 	}
 
 	if (!strncmp(sleep_type, "s2idle", strlen("s2idle"))) {
-		uint32_t residency = get_s2_idle_residency();
+		uint64_t residency = get_s2_idle_residency();
 		bool intel;
 		if (fwts_cpu_is_Intel(&intel) == FWTS_OK && intel && residency <= *s2idle_residency) {
 			(*s2idle_errors)++;
 			fwts_failed(fw, LOG_LEVEL_HIGH, "S2idleNotDeepest",
-				"Expected %s to increase from %" PRIu32 ", got %" PRIu32 ".",
-				PM_S2IDLE_SLP_S0, residency, *s2idle_residency);
+				"Expected %s to increase from %" PRIu64 ", got %" PRIu64 ".",
+				PM_S2IDLE_SLP_S0, *s2idle_residency, residency);
 		}
 		*s2idle_residency = residency;
 	}
@@ -564,7 +589,7 @@ static int s3_test_multiple(fwts_framework *fw)
 	int resume_too_long = 0;
 	int awake_delay = s3_min_delay * 1000;
 	int delta = (int)(s3_delay_delta * 1000.0);
-	uint32_t s2idle_residency = get_s2_idle_residency();
+	uint64_t s2idle_residency = get_s2_idle_residency();
 	int pm_debug;
 
 #if FWTS_ENABLE_LOGIND
@@ -808,6 +833,9 @@ static int s3_options_handler(fwts_framework *fw, int argc, char * const argv[],
 		case 11:
 			s3_hook = optarg;
 			break;
+		case 12:
+			s3_sleep_type = optarg;
+			break;
 		}
 	}
 	return FWTS_OK;
@@ -826,6 +854,7 @@ static fwts_option s3_options[] = {
 	{ "s3-resume-time", 	"", 1, "Maximum expected resume time in seconds, e.g. --s3-resume-time=5.1" },
 	{ "s3-hybrid",		"", 0, "Run S3 with hybrid sleep, i.e. saving system states as S4 does." },
 	{ "s3-resume-hook hook","", 1, "Run a hook script after each S3 resume, 0 exit indicates success." },
+	{ "s3-sleep-type"	,"", 1, "Set the sleep type for testing S3 or s2idle, default S3." },
 	{ NULL, NULL, 0, NULL }
 };
 
@@ -837,6 +866,7 @@ static fwts_framework_minor_test s3_tests[] = {
 static fwts_framework_ops s3_ops = {
 	.description = "Sleep suspend/resume test.",
 	.init        = s3_init,
+	.deinit      = s3_deinit,
 	.minor_tests = s3_tests,
 	.options     = s3_options,
 	.options_handler = s3_options_handler,
