@@ -70,7 +70,7 @@ static int sbst_test1(fwts_framework *fw)
 }
 
 static fwts_framework_minor_test sbst_tests[] = {
-	{ sbst_test1, "SBST Smart Battery Specificiation Table test." },
+	{ sbst_test1, "SBST Smart Battery Specification Table test." },
 	{ NULL, NULL }
 };
 
@@ -80,6 +80,6 @@ static fwts_framework_ops sbst_ops = {
 	.minor_tests = sbst_tests
 };
 
-FWTS_REGISTER("sbst", &sbst_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("sbst", &sbst_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
