@@ -37,13 +37,8 @@ static int spcr_init(fwts_framework *fw)
 		return FWTS_ERROR;
 	}
 	if (table == NULL || (table && table->length == 0)) {
-		if (fw->flags & FWTS_FLAG_TEST_SBBR) {
-			fwts_log_error(fw, "ACPI SPCR table does not exist");
-			return FWTS_ERROR;
-		} else {
-			fwts_log_error(fw, "ACPI SPCR table does not exist, skipping test");
-			return FWTS_SKIP;
-		}
+		fwts_log_error(fw, "ACPI SPCR table does not exist, skipping test");
+		return FWTS_SKIP;
 	}
 	spcr = (const fwts_acpi_table_spcr*)table->data;
 
@@ -57,7 +52,7 @@ static int spcr_init(fwts_framework *fw)
  */
 static int spcr_sbbr_revision_test(fwts_framework *fw)
 {
-	if (fw->flags & FWTS_FLAG_TEST_SBBR) {
+	if (fw->flags & FWTS_FLAG_SBBR) {
 		const uint8_t SBBR_LATEST_REVISION = 2;
 
 		if (spcr->header.revision >= SBBR_LATEST_REVISION)
@@ -72,7 +67,7 @@ static int spcr_sbbr_revision_test(fwts_framework *fw)
 
 static int spcr_sbbr_gsiv_test(fwts_framework *fw)
 {
-	if (fw->flags & FWTS_FLAG_TEST_SBBR) {
+	if (fw->flags & FWTS_FLAG_SBBR) {
 		const uint8_t ARMH_GIC_INTR_MASK = 0x08;
 		const uint8_t IO_APIC_INTR_MASK = 0x02;
 
@@ -143,7 +138,7 @@ static int spcr_test1(fwts_framework *fw)
 	}
 
 	reserved1 = spcr->reserved1[0] + (spcr->reserved1[1] << 8) + (spcr->reserved1[2] << 16);
-	fwts_acpi_reserved_zero_check("SPCR", "Reserved1", reserved1, &passed);
+	fwts_acpi_reserved_zero("SPCR", "Reserved1", reserved1, &passed);
 
 	if (spcr->interrupt_type == 0) {
 		passed = false;
@@ -177,6 +172,9 @@ static int spcr_test1(fwts_framework *fw)
 
 	reserved = false;
 	switch (spcr->baud_rate) {
+	case 0x00:
+		str = "preconfigured in firmware";
+		break;
 	case 0x03:
 		str = "9600";
 		break;
@@ -202,9 +200,9 @@ static int spcr_test1(fwts_framework *fw)
 			" is a reserved baud rate", spcr->baud_rate);
 	}
 
-	fwts_acpi_fixed_value_check(fw, LOG_LEVEL_HIGH, "SPCR", "Parity", spcr->parity, 0, &passed);
-	fwts_acpi_fixed_value_check(fw, LOG_LEVEL_HIGH, "SPCR", "Stop", spcr->stop_bits, 1, &passed);
-	fwts_acpi_reserved_bits_check("SPCR", "Flow control", spcr->flow_control, 3, 7, &passed);
+	fwts_acpi_fixed_value(fw, LOG_LEVEL_HIGH, "SPCR", "Parity", spcr->parity, 0, &passed);
+	fwts_acpi_fixed_value(fw, LOG_LEVEL_HIGH, "SPCR", "Stop", spcr->stop_bits, 1, &passed);
+	fwts_acpi_reserved_bits("SPCR", "Flow control", spcr->flow_control, 3, 7, &passed);
 
 	reserved = false;
 	switch (spcr->terminal_type) {
@@ -233,7 +231,7 @@ static int spcr_test1(fwts_framework *fw)
 			" is a reserved terminal type", spcr->terminal_type);
 	}
 
-	fwts_acpi_reserved_zero_check("SPCR", "Reserved2", spcr->reserved2, &passed);
+	fwts_acpi_reserved_zero("SPCR", "Reserved2", spcr->reserved2, &passed);
 
 	/* According to the spec, these values indicate NOT a PCI device */
 	if ((spcr->pci_device_id == 0xffff) &&
@@ -271,8 +269,8 @@ static int spcr_test1(fwts_framework *fw)
 		}
 	}
 
-	fwts_acpi_reserved_bits_check("SPCR", "PCI Flags", spcr->pci_flags, 1, 31, &passed);
-	fwts_acpi_reserved_zero_check("SPCR", "Reserved3", spcr->reserved3, &passed);
+	fwts_acpi_reserved_bits("SPCR", "PCI Flags", spcr->pci_flags, 1, 31, &passed);
+	fwts_acpi_reserved_zero("SPCR", "Reserved3", spcr->reserved3, &passed);
 
 	if (passed)
 		fwts_passed(fw, "No issues found in SPCR table.");
@@ -293,6 +291,6 @@ static fwts_framework_ops spcr_ops = {
 	.minor_tests = spcr_tests
 };
 
-FWTS_REGISTER("spcr", &spcr_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI | FWTS_FLAG_TEST_SBBR)
+FWTS_REGISTER("spcr", &spcr_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI | FWTS_FLAG_SBBR)
 
 #endif
