@@ -49,7 +49,7 @@ static int tpm2_test1(fwts_framework *fw)
 			tpm2->platform_class);
 	}
 
-	fwts_acpi_reserved_zero_check("TPM2", "Reserved", tpm2->reserved, &passed);
+	fwts_acpi_reserved_zero("TPM2", "Reserved", tpm2->reserved, &passed);
 
 	if (tpm2->start_method < 1 || tpm2->start_method >= 12) {
 		passed = false;
@@ -97,6 +97,6 @@ static fwts_framework_ops tpm2_ops = {
 	.minor_tests = tpm2_tests
 };
 
-FWTS_REGISTER("tpm2", &tpm2_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("tpm2", &tpm2_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
