@@ -49,7 +49,7 @@ static int uefi_test1(fwts_framework *fw)
 						0x9d, 0x94, 0xdb, 0x65, 0xac, 0xc5, 0xc3, 0x32 };
 
 	/* Enough length for the uefi table? */
-	if (!fwts_acpi_table_length_check(fw, "UEFI", table->length, sizeof(fwts_acpi_table_uefi))) {
+	if (!fwts_acpi_table_length(fw, "UEFI", table->length, sizeof(fwts_acpi_table_uefi))) {
 		passed = false;
 		goto done;
 	}
@@ -74,7 +74,7 @@ static int uefi_test1(fwts_framework *fw)
 	if (memcmp(uefi->uuid, guid_smm, 16) == 0) {
 		fwts_acpi_table_uefi_smmcomm *uefi_smmcomm = (fwts_acpi_table_uefi_smmcomm *)table->data;
 
-		/* chekc the dataoffset for SMM Comm table */
+		/* check the dataoffset for SMM Comm table */
 		if (uefi_smmcomm->boot.dataoffset != 54) {
 			passed = false;
 			fwts_failed(fw, LOG_LEVEL_HIGH,
@@ -115,6 +115,6 @@ static fwts_framework_ops uefi_ops = {
 	.minor_tests = uefi_tests
 };
 
-FWTS_REGISTER("uefi", &uefi_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("uefi", &uefi_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
