@@ -111,6 +111,10 @@ static bool is_uniqueid_equal(acpi_ids *obj1, acpi_ids *obj2)
 	if (obj1 == NULL || obj2 == NULL)
 		return false;
 
+	/* _HID and _CID are in the same device */
+	if (!strncmp(obj1->hid_name, obj2->hid_name, strlen(obj1->hid_name) - 4))
+		return false;
+
 	if ((obj1->hid_obj->Type != obj2->hid_obj->Type) || (obj1->uid_obj->Type != obj2->uid_obj->Type))
 		return false;
 
