@@ -80,13 +80,21 @@ static fwts_wmi_known_guid fwts_wmi_known_guids[] = {
 	{ "A70591CE-A997-11DA-B012-B622A1EF5492", "alienware-wmi", "Alienware" },
 	{ "0B3CBB35-E3C2-45ED-91C2-4C5A6D195D1C", "asus-nb-wmi","Asus" },
 	{ "97845ED0-4E6D-11DE-8A39-0800200C9A66", "asus-wmi",	"Asus" },
-	{ "9DBB5994-A997-11DA-B012-B622A1EF5492", "dell-wmi",	"Dell" },
-	{ "8D9DDCBC-A997-11DA-B012-B622A1EF5492", "dell-wmi",	"Dell" },
+	{ "9DBB5994-A997-11DA-B012-B622A1EF5492", "dell-wmi-base", "Dell" },
+	{ "8D9DDCBC-A997-11DA-B012-B622A1EF5492", "dell-wmi-descriptor", "Dell" },
 	{ "284A0E6B-380E-472A-921F-E52786257FB4", "dell-wmi-aio","Dell" },
 	{ "02314822-307C-4F66-BF0E-48AEAEB26CC8", "dell-wmi-aio","Dell" },
 	{ "F6E4FE6E-909D-47cb-8BAB-C9F6F2F8D396", "dell-wmi-led","Dell" },
+	{ "6932965F-1671-4CEB-B988-D3AB0A901919", "dell-wmi-privacy", "Dell" },
+	{ "F1DDEE52-063C-4784-A11E-8A06684B9BF5", "dell-wmi-sysman", "Dell" },
+	{ "F1DDEE52-063C-4784-A11E-8A06684B9BFA", "dell-wmi-sysman", "Dell" },
+	{ "F1DDEE52-063C-4784-A11E-8A06684B9BF9", "dell-wmi-sysman", "Dell" },
+	{ "0894B8D6-44A6-4719-97D7-6AD24108BFD4", "dell-wmi-sysman", "Dell" },
+	{ "F1DDEE52-063C-4784-A11E-8A06684B9BF4", "dell-wmi-sysman", "Dell" },
+	{ "70FE8229-D03B-4214-A1C6-1F884B1A892A", "dell-wmi-sysman", "Dell" },
 	{ "ABBC0F72-8EA1-11D1-00A0-C90629100000", "eeepc-wmi",	"Asus" },
 	{ "97845ED0-4E6D-11DE-8A39-0800200C9A66", "eeepc-wmi",	"Asus" },
+	{ "DEADBEEF-2001-0000-00A0-C90629100000", "gigabyte-wmi",	"Gigabyte" },
 	{ "95F24279-4D7B-4334-9387-ACCDC67EF61C", "hp-wmi",	"HP"   },
 	{ "5FB7F034-2C63-45e9-BE91-3D44E2C707E4", "hp-wmi",	"HP"   },
 	{ "ABBC0F5B-8EA1-11D1-A000-C90629100000", "huawei-wmi", "Huawei" },
@@ -106,6 +114,12 @@ static fwts_wmi_known_guid fwts_wmi_known_guids[] = {
 	{ "5B3CC38A-40D9-7245-8AE6-1145B751BE3F", "msi-wmi",	"MSI"  },
 	{ "F6CB5C3C-9CAE-4EBD-B577-931EA32A2CC0", "mxm-wmi",	"MXM"  },
 	{ "ABBC0F6F-8EA1-11D1-00A0-C90629100000", "peaq-wmi",	"PEAQ"  },
+	{ "51F5230E-9677-46CD-A1CF-C0B23EE34DB7", "think-lmi", "Lenovo" },
+	{ "98479A64-33F5-4E33-A707-8E251EBBC3A1", "think-lmi", "Lenovo" },
+	{ "6A4B54EF-A5ED-4D33-9455-B0D9B48DF4B3", "think-lmi", "Lenovo" },
+	{ "8ADB159E-1E32-455C-BC93-308A7ED98246", "think-lmi", "Lenovo" },
+	{ "2651D9FD-911C-4B69-B94E-D0DED5963BD7", "think-lmi", "Lenovo" },
+	{ "7364651A-132F-4FE7-ADAA-40C6C7EE2E3B", "think-lmi", "Lenovo" },
 	{ "F7CC25EC-D20B-404C-8903-0ED4359C18AE", "surface3-wmi", "Surface3" },
 	{ "C364AC71-36DB-495A-8494-B439D472A505", "tc110-wmi",	"HP Compaq" },
 	{ "59142400-C6A3-40FA-BADB-8A2652834100", "toshiba_acpi", "Toshiba" },
@@ -426,6 +440,6 @@ static fwts_framework_ops wmi_ops = {
 	.minor_tests = wmi_tests
 };
 
-FWTS_REGISTER("wmi", &wmi_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("wmi", &wmi_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
