@@ -41,7 +41,7 @@ static int wsmt_test1(fwts_framework *fw)
 	fwts_log_info_verbatim(fw, "WSMT Windows SMM Security Mitigations Table:");
 	fwts_log_info_simp_int(fw, "  Protection Flags:      ", wsmt->protection_flags);
 
-	fwts_acpi_reserved_bits_check("WSMT", "Protection Flags", wsmt->protection_flags, 3, 31, &passed);
+	fwts_acpi_reserved_bits("WSMT", "Protection Flags", wsmt->protection_flags, 3, 31, &passed);
 
 	if ((wsmt->protection_flags & 0x2) && !(wsmt->protection_flags & 0x1)) {
 		passed = false;
@@ -70,6 +70,6 @@ static fwts_framework_ops wsmt_ops = {
 	.minor_tests = wsmt_tests
 };
 
-FWTS_REGISTER("wsmt", &wsmt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+FWTS_REGISTER("wsmt", &wsmt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
