@@ -51,7 +51,7 @@ static int xenv_test1(fwts_framework *fw)
 	fwts_log_info_simp_int(fw, "  Evtchn Intr:                     ", xenv->evtchn_intr);
 	fwts_log_info_simp_int(fw, "  Evtchn Intr Flags:               ",  xenv->evtchn_intr_flags);
 
-	fwts_acpi_reserved_bits_check("XENV", "Evtchn Intr Flags", xenv->evtchn_intr_flags, 2, 7, &passed);
+	fwts_acpi_reserved_bits("XENV", "Evtchn Intr Flags", xenv->evtchn_intr_flags, 2, 7, &passed);
 
 	if (passed)
 		fwts_passed(fw, "No issues found in XENV table.");
@@ -71,6 +71,6 @@ static fwts_framework_ops xenv_check_ops = {
 };
 
 FWTS_REGISTER("xenv", &xenv_check_ops, FWTS_TEST_ANYTIME,
-	FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI)
+	FWTS_FLAG_BATCH | FWTS_FLAG_ACPI)
 
 #endif
