@@ -27,24 +27,7 @@
 #include <string.h>
 
 static fwts_acpi_table_info *table;
-
-static int xsdt_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "XSDT", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		if (fw->flags & FWTS_FLAG_TEST_SBBR) {
-			fwts_log_error(fw, "ACPI XSDT table does not exist");
-			return FWTS_ERROR;
-		} else {
-			fwts_log_error(fw, "ACPI XSDT table does not exist, skipping test");
-			return FWTS_SKIP;
-		}
-	}
-	return FWTS_OK;
-}
+acpi_table_init(XSDT, &table)
 
 /*
  *  XSDT Extended System Description Table
@@ -59,7 +42,7 @@ static int xsdt_test1(fwts_framework *fw)
 	for (i = 0; i < n; i++) {
 		if (xsdt->entries[i] == 0) {
 			passed = false;
-			if (fw->flags & FWTS_FLAG_TEST_SBBR) {
+			if (fw->flags & FWTS_FLAG_SBBR) {
 				fwts_failed(fw, LOG_LEVEL_CRITICAL,
 					"XSDTEntryNull",
 					"XSDT Entry %zd is null, should not be non-zero.", i);
@@ -78,7 +61,7 @@ static int xsdt_test1(fwts_framework *fw)
 		}
 	}
 	if (passed) {
-		if (fw->flags & FWTS_FLAG_TEST_SBBR) {
+		if (fw->flags & FWTS_FLAG_SBBR) {
 			fwts_passed(fw, "XSDT is present, pointed at by XsdrAddress=0x%" PRIx64
 				" and contain valid pointers to %d other ACPI tables mandated by SBBR",
 				 xsdt->entries[0], (int)n);
@@ -96,10 +79,10 @@ static fwts_framework_minor_test xsdt_tests[] = {
 
 static fwts_framework_ops xsdt_ops = {
 	.description = "XSDT Extended System Description Table test.",
-	.init        = xsdt_init,
+	.init        = XSDT_init,
 	.minor_tests = xsdt_tests
 };
 
-FWTS_REGISTER("xsdt", &xsdt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_TEST_ACPI | FWTS_FLAG_TEST_SBBR)
+FWTS_REGISTER("xsdt", &xsdt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH | FWTS_FLAG_ACPI | FWTS_FLAG_SBBR)
 
 #endif
