@@ -541,6 +541,11 @@ TrTransformSubtree (
         AslError (ASL_WARNING, ASL_MSG_LEGACY_PROCESSOR_OP, Op, Op->Asl.ExternalName);
         break;
 
+    case PARSEOP_OBJECTTYPE_DDB:
+
+        AslError (ASL_WARNING, ASL_MSG_LEGACY_DDB_TYPE, Op, Op->Asl.ExternalName);
+        break;
+
     default:
 
         /* Nothing to do here for other opcodes */
