@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2020, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2021, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -400,6 +400,10 @@ AcpiDmIsUuidBuffer (
     /* Buffer size is the buffer argument */
 
     SizeOp = Op->Common.Value.Arg;
+    if (!SizeOp)
+    {
+        return (FALSE);
+    }
 
     /* Next, the initializer byte list to examine */
 
@@ -490,6 +494,10 @@ AcpiDmUuid (
     {
         AcpiOsPrintf (" /* %s */", Description);
     }
+    else
+    {
+        AcpiOsPrintf (" /* Unknown UUID */");
+    }
 }
 
 
@@ -520,6 +528,10 @@ AcpiDmIsUnicodeBuffer (
     /* Buffer size is the buffer argument */
 
     SizeOp = Op->Common.Value.Arg;
+    if (!SizeOp)
+    {
+        return (FALSE);
+    }
 
     /* Next, the initializer byte list to examine */
 
@@ -596,6 +608,10 @@ AcpiDmIsStringBuffer (
     /* Buffer size is the buffer argument */
 
     SizeOp = Op->Common.Value.Arg;
+    if (!SizeOp)
+    {
+        return (FALSE);
+    }
 
     /* Next, the initializer byte list to examine */
 
@@ -675,13 +691,18 @@ AcpiDmIsPldBuffer (
     UINT64                  InitializerSize;
 
 
+    if (!Op)
+    {
+        return (FALSE);
+    }
+
     /*
      * Get the BufferSize argument - Buffer(BufferSize)
      * If the buffer was generated by the ToPld macro, it must
      * be a BYTE constant.
      */
     SizeOp = Op->Common.Value.Arg;
-    if (SizeOp->Common.AmlOpcode != AML_BYTE_OP)
+    if (!SizeOp || SizeOp->Common.AmlOpcode != AML_BYTE_OP)
     {
         return (FALSE);
     }
