@@ -216,7 +216,7 @@ AcpiRsConvertAmlToResources (
         }
         else
         {
-            /* This is an I2C, SPI, or UART SerialBus descriptor */
+            /* This is an I2C, SPI, UART, or CSI2 SerialBus descriptor */
 
             ConversionTable = AcpiGbl_ConvertResourceSerialBusDispatch [
                 AmlResource->CommonSerialBus.Type];
@@ -246,6 +246,12 @@ AcpiRsConvertAmlToResources (
         return_ACPI_STATUS (Status);
     }
 
+    if (!Resource->Length)
+    {
+        ACPI_EXCEPTION ((AE_INFO, Status,
+            "Zero-length resource returned from RsConvertAmlToResource"));
+    }
+
     ACPI_DEBUG_PRINT ((ACPI_DB_RESOURCES,
         "Type %.2X, AmlLength %.2X InternalLength %.2X\n",
         AcpiUtGetResourceType (Aml), Length,
@@ -326,7 +332,7 @@ AcpiRsConvertResourcesToAml (
             }
             else
             {
-                /* This is an I2C, SPI, or UART SerialBus descriptor */
+                /* This is an I2C, SPI, UART or CSI2 SerialBus descriptor */
 
                 ConversionTable = AcpiGbl_ConvertResourceSerialBusDispatch[
                     Resource->Data.CommonSerialBus.Type];
