@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2020, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2021, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -192,6 +192,7 @@ typedef enum
     ACPI_RSC_1BITFLAG,
     ACPI_RSC_2BITFLAG,
     ACPI_RSC_3BITFLAG,
+    ACPI_RSC_6BITFLAG,
     ACPI_RSC_ADDRESS,
     ACPI_RSC_BITMASK,
     ACPI_RSC_BITMASK16,
@@ -252,6 +253,7 @@ typedef enum
     ACPI_RSD_1BITFLAG,
     ACPI_RSD_2BITFLAG,
     ACPI_RSD_3BITFLAG,
+    ACPI_RSD_6BITFLAG,
     ACPI_RSD_ADDRESS,
     ACPI_RSD_DWORDLIST,
     ACPI_RSD_LITERAL,
@@ -495,6 +497,7 @@ extern ACPI_RSCONVERT_INFO      AcpiRsConvertAddress64[];
 extern ACPI_RSCONVERT_INFO      AcpiRsConvertExtAddress64[];
 extern ACPI_RSCONVERT_INFO      AcpiRsConvertGpio[];
 extern ACPI_RSCONVERT_INFO      AcpiRsConvertFixedDma[];
+extern ACPI_RSCONVERT_INFO      AcpiRsConvertCsi2SerialBus[];
 extern ACPI_RSCONVERT_INFO      AcpiRsConvertI2cSerialBus[];
 extern ACPI_RSCONVERT_INFO      AcpiRsConvertSpiSerialBus[];
 extern ACPI_RSCONVERT_INFO      AcpiRsConvertUartSerialBus[];
@@ -550,6 +553,7 @@ extern ACPI_RSDUMP_INFO         AcpiRsDumpGpio[];
 extern ACPI_RSDUMP_INFO         AcpiRsDumpPinFunction[];
 extern ACPI_RSDUMP_INFO         AcpiRsDumpFixedDma[];
 extern ACPI_RSDUMP_INFO         AcpiRsDumpCommonSerialBus[];
+extern ACPI_RSDUMP_INFO         AcpiRsDumpCsi2SerialBus[];
 extern ACPI_RSDUMP_INFO         AcpiRsDumpI2cSerialBus[];
 extern ACPI_RSDUMP_INFO         AcpiRsDumpSpiSerialBus[];
 extern ACPI_RSDUMP_INFO         AcpiRsDumpUartSerialBus[];
