@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2020, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2021, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -195,7 +195,9 @@ typedef struct ae_debug_regions
 typedef struct init_file_entry
 {
     char                    *Name;
+    char                    *Value;
     ACPI_OPERAND_OBJECT     *ObjDesc;
+    BOOLEAN                 IsUsed;
 
 } INIT_FILE_ENTRY;
 
@@ -346,19 +348,23 @@ int
 AeOpenInitializationFile (
     char                    *Filename);
 
-void
+ACPI_STATUS
 AeProcessInitFile (
     void);
 
-ACPI_STATUS
-AeSetupConfiguration (
-    void                    *RegionAddr);
-
 ACPI_STATUS
 AeLookupInitFileEntry (
     char                    *Pathname,
     ACPI_OPERAND_OBJECT     **ObjDesc);
 
+void
+AeDisplayUnusedInitFileItems (
+    void);
+
+void
+AeDeleteInitFileList (
+    void);
+
 /* aeexec */
 
 void
@@ -376,6 +382,10 @@ AeGetDevices (
     void                    *Context,
     void                    **ReturnValue);
 
+ACPI_STATUS
+AeSetupConfiguration (
+    void                    *RegionAddr);
+
 ACPI_STATUS
 ExecuteOSI (
     char                    *OsiString,
