@@ -26,19 +26,23 @@
 #include <getopt.h>
 
 typedef struct {
-	char		*long_name;	/* e.g. "quiet", long name */
-	char		*short_name;	/* e.g. "q", short help info */
-	int		has_arg;
-	char		*explanation;	/* explanation: "Enabled quiet mode..." */
+	const char *long_name;		/* e.g. "quiet", long name */
+	const char *short_name;		/* e.g. "q", short help info */
+	const int  has_arg;
+	const char *explanation;	/* explanation: "Enabled quiet mode..." */
 } fwts_option;
 
 #include "fwts.h"
 
-typedef int (*fwts_args_optarg_handler)(fwts_framework *framework, int argc, char * const argv[], int option_char, int long_index);
+typedef int (*fwts_args_optarg_handler)(fwts_framework *framework,
+	const int argc, char * const argv[], const int option_char,
+	const int long_index);
 typedef int (*fwts_args_optarg_check)(fwts_framework *framework);
 
 int fwts_args_init(void);
-int fwts_args_add_options(fwts_option *options, fwts_args_optarg_handler handler, fwts_args_optarg_check check);
+int fwts_args_add_options(fwts_option *options,
+	const fwts_args_optarg_handler handler,
+	const fwts_args_optarg_check check);
 int fwts_args_parse(fwts_framework *fw, const int argc, char * const argv[]);
 void fwts_args_show_options(void);
 int fwts_args_free(void);
