@@ -23,7 +23,7 @@
 int fwts_lib_efi_runtime_load_module(fwts_framework *fw);
 int fwts_lib_efi_runtime_unload_module(fwts_framework *fw);
 int fwts_lib_efi_runtime_open(void);
-int fwts_lib_efi_runtime_close(int fd);
+int fwts_lib_efi_runtime_close(const int fd);
 int fwts_lib_efi_runtime_kernel_lockdown(fwts_framework *fw);
 int fwts_lib_efi_runtime_module_init(fwts_framework *fw, int *fd);
 
