@@ -21,8 +21,11 @@
 #define __FWTS_FILEIO_H__
 
 #include <stdio.h>
+#include <zlib.h>
 
 fwts_list* fwts_file_read(FILE *fp);
 fwts_list* fwts_file_open_and_read(const char *file);
+fwts_list* fwts_gzfile_read(gzFile *fp);
+fwts_list* fwts_gzfile_open_and_read(const char *file);
 
 #endif
