@@ -54,25 +54,18 @@ typedef enum {
 	FWTS_FLAG_ROOT_PRIV			= 0x00002000,
 	FWTS_FLAG_UNSAFE			= 0x00004000,
 	FWTS_FLAG_FIRMWARE_VENDOR		= 0x00008000,
-	FWTS_FLAG_TEST_BIOS			= 0x00010000,
-	FWTS_FLAG_TEST_UEFI			= 0x00020000,
-	FWTS_FLAG_TEST_ACPI			= 0x00040000,
+	FWTS_FLAG_UEFI				= 0x00020000,
+	FWTS_FLAG_ACPI				= 0x00040000,
 	FWTS_FLAG_UTILS				= 0x00080000,
 	FWTS_FLAG_QUIET				= 0x00100000,
 	FWTS_FLAG_SHOW_TESTS_FULL		= 0x00200000,
 	FWTS_FLAG_SHOW_TESTS_CATEGORIES		= 0x00400000,
-	FWTS_FLAG_TEST_COMPLIANCE_ACPI		= 0x00800000,
-	FWTS_FLAG_TEST_SBBR			= 0x01000000,
-	FWTS_FLAG_TEST_EBBR			= 0x02000000,
-	FWTS_FLAG_TEST_XBBR			= FWTS_FLAG_TEST_SBBR | FWTS_FLAG_TEST_EBBR
+	FWTS_FLAG_COMPLIANCE_ACPI		= 0x00800000,
+	FWTS_FLAG_SBBR				= 0x01000000,
+	FWTS_FLAG_EBBR				= 0x02000000,
+	FWTS_FLAG_XBBR				= FWTS_FLAG_SBBR | FWTS_FLAG_EBBR
 } fwts_framework_flags;
 
-#define FWTS_FLAG_TEST_MASK		\
-	(FWTS_FLAG_TEST_BIOS |	\
-	 FWTS_FLAG_TEST_UEFI |	\
-	 FWTS_FLAG_TEST_ACPI |  \
-	 FWTS_FLAG_TEST_SBBR)
-
 /*
  *  Test results
  */
