@@ -36,8 +36,11 @@ typedef struct {
 
 void fwts_gpe_free(fwts_gpe *gpe, const int count);
 int  fwts_gpe_read(fwts_gpe **gpes);
-int  fwts_gpe_delta(int **gpe_delta, const fwts_gpe *start, const fwts_gpe *end, const int n);
-int  fwts_gpe_delta_get(fwts_framework *fw, const fwts_gpe *gpes_start, const fwts_gpe *gpes_end, const int gpe_count, int *sci, int *gpe);
-void fwts_gpe_test(fwts_framework *fw, const fwts_gpe *start, const fwts_gpe *end, const int n);
+int  fwts_gpe_delta(int **gpe_delta, const fwts_gpe *start,
+	const fwts_gpe *end, const int n);
+int  fwts_gpe_delta_get(fwts_framework *fw, const fwts_gpe *gpes_start,
+	const fwts_gpe *gpes_end, const int gpe_count, int *sci, int *gpe);
+void fwts_gpe_test(fwts_framework *fw, const fwts_gpe *start,
+	const fwts_gpe *end, const int n);
 
 #endif
