@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2020 Canonical
+ * Copyright (C) 2013-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -151,6 +151,8 @@
 #define FWTS_PCI_SUBCLASS_CODE_OTHER_SYSTEM_PERIPHERAL	(0x80)
 #define FWTS_PCI_SUBCLASS_CODE_AUDIO_DEVICE		(0x03)
 
+/* PCI Vendor IDs */
+#define FWTS_PCI_INTEL_VENDOR_ID			(0x8086)
 
 /*
  * PCI Express Capability Structure is defined in Section 7.8
@@ -183,6 +185,14 @@ typedef struct {
  	uint16_t slot_status2;
 } __attribute__ ((packed)) fwts_pcie_capability;
 
+typedef struct {
+	uint8_t segment;
+	uint8_t bus;
+	uint8_t dev;
+	uint8_t func;
+	uint8_t config[256];
+} fwts_pci_device;
+
 const char *fwts_pci_description(const uint8_t class_code, const uint8_t subclass_code);
 
 #endif
