@@ -78,10 +78,9 @@ int fwts_ac_adapter_get_state(const int state, int *matching, int *not_matching)
 
 	/* Try to user newer /sys interface first */
 	if ((ac_power_dir = opendir(FWTS_SYS_CLASS_POWER_SUPPLY))) {
-		struct dirent *ac_entry;
 		int count = 0;
 
-		while ((ac_entry = readdir(ac_power_dir)) != NULL)
+		while (readdir(ac_power_dir) != NULL)
 			count++;
 
 		/* no power supply dir exists */
