@@ -18,8 +18,6 @@
  */
 #include "fwts.h"
 
-#if defined(FWTS_HAS_ACPI)
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
@@ -194,7 +192,7 @@ static const acpi_eval_error errors[] = {
 		"A method attempted to use an empty element in an ACPI package."
 	},
 	{ AE_AML_NUMERIC_OVERFLOW, 	LOG_LEVEL_HIGH,		"AEAMLNumericOverflow",	"Numeric overflow",
-		"A numeric overflow occurred, for example when coverting a BCD value."
+		"A numeric overflow occurred, for example when converting a BCD value."
 	},
 	{ AE_AML_REGION_LIMIT, 		LOG_LEVEL_CRITICAL,	"AEAMLRegionLimit",	"Region limit",
 		"An attempt to access beyond the end of an ACPI Operation Region occurred."
@@ -206,7 +204,7 @@ static const acpi_eval_error errors[] = {
 		"An attempt to access beyond the endof an ACPI package occurred."
 	},
 	{ AE_AML_DIVIDE_BY_ZERO, 	LOG_LEVEL_CRITICAL,	"AEAMLDivideByZero",	"Division by zero",
-		"A division by zero error occurred while excuting the AML Divide op-code"
+		"A division by zero error occurred while executing the AML Divide op-code"
 	},
 	{ AE_AML_NAME_NOT_FOUND, 	LOG_LEVEL_HIGH,		"AEAMLNameNotFound",	"Name not found",
 		"An ACPI named reference could not be resolved."
@@ -234,7 +232,7 @@ static const acpi_eval_error errors[] = {
 	{ AE_AML_MUTEX_ORDER, 		LOG_LEVEL_HIGH,		"AEAMLMutexOrder",	"Mutex order",
 		"Deadlock prevention has detected that the current mutex sync level is too large."
 	},
-	{ AE_AML_MUTEX_NOT_ACQUIRED, 	LOG_LEVEL_HIGH,		"AEAMLMutexNotAcq",	"Mutux not acquired",
+	{ AE_AML_MUTEX_NOT_ACQUIRED, 	LOG_LEVEL_HIGH,		"AEAMLMutexNotAcq",	"Mutex not acquired",
 		"An attempt was made to release a mutex that had not been acquired."
 	},
 	{ AE_AML_INVALID_RESOURCE_TYPE, LOG_LEVEL_HIGH,		"AEAMLInvResourceType", "Invalid resource type",
@@ -245,7 +243,7 @@ static const acpi_eval_error errors[] = {
 		"ArgN or LocalN were N was out of range."
 	},
 	{ AE_AML_REGISTER_LIMIT, 	LOG_LEVEL_HIGH,		"AEAMLRegisterLimit",	"Register limit",
-		"An attempt to use a bank value that is beyong the capacity of a register occurred."
+		"An attempt to use a bank value that is beyond the capacity of a register occurred."
 	},
 	{ AE_AML_NO_WHILE, 		LOG_LEVEL_CRITICAL,	"AEAMLNoWhile",		"No while",
 		"A Break or Continue op-code was reached without a matching While op-code."
@@ -474,10 +472,10 @@ ACPI_STATUS fwts_acpi_object_evaluate(fwts_framework *fw,
 
 int fwts_method_check_type__(
 	fwts_framework *fw,
-	char *name,
-	ACPI_BUFFER *buf,
-	ACPI_OBJECT_TYPE type,
-	char *type_name)
+	const char *name,
+	const ACPI_BUFFER *buf,
+	const ACPI_OBJECT_TYPE type,
+	const char *type_name)
 {
 	ACPI_OBJECT *obj;
 
@@ -509,38 +507,6 @@ static void get_object_name(const char *name, char* obj_name) {
 	}
 }
 
-/* See references in actypes.h */
-static const char *acpi_object_names[] = {
-	"Any",
-	"Integer",
-	"String",
-	"Buffer",
-	"Package",
-	"Field Unit",
-	"Device",
-	"Event",
-	"Method",
-	"Mutex",
-	"Region",
-	"Power",
-	"Processor",
-	"Thermal",
-	"Buffer Field",
-	"DDB Handle",
-	"Debug Object",
-	"Region Field",
-	"Bank Field",
-	"Index Field",
-	"Reference",
-	"Alias",
-	"Method Alias",
-	"Notify",
-	"Address Handler",
-	"Resource",
-	"Resource Field",
-	"Scope"
-};
-
 /*
  *  fwts_method_check_element_type()
  *	check a element type of a sub-package
@@ -548,11 +514,43 @@ static const char *acpi_object_names[] = {
 int fwts_method_check_element_type(
 	fwts_framework *fw,
 	const char *name,
-	ACPI_OBJECT *obj,
-	uint32_t subpkg,
-	uint32_t element,
-	ACPI_OBJECT_TYPE type)
+	const ACPI_OBJECT *obj,
+	const uint32_t subpkg,
+	const uint32_t element,
+	const ACPI_OBJECT_TYPE type)
 {
+	/* See references in actypes.h */
+	static const char *acpi_object_names[] = {
+		"Any",
+		"Integer",
+		"String",
+		"Buffer",
+		"Package",
+		"Field Unit",
+		"Device",
+		"Event",
+		"Method",
+		"Mutex",
+		"Region",
+		"Power",
+		"Processor",
+		"Thermal",
+		"Buffer Field",
+		"DDB Handle",
+		"Debug Object",
+		"Region Field",
+		"Bank Field",
+		"Index Field",
+		"Reference",
+		"Alias",
+		"Method Alias",
+		"Notify",
+		"Address Handler",
+		"Resource",
+		"Resource Field",
+		"Scope"
+	};
+
 	if (obj->Package.Elements[element].Type != type) {
 		char obj_name[5] = "_XYZ";
 		char tmp[128];
@@ -642,7 +640,9 @@ void fwts_method_failed_null_object(
 		"return %s.", name, type);
 }
 
-bool fwts_method_type_matches(ACPI_OBJECT_TYPE t1, ACPI_OBJECT_TYPE t2)
+bool fwts_method_type_matches(
+	const ACPI_OBJECT_TYPE t1,
+	const ACPI_OBJECT_TYPE t2)
 {
 	if (t1 == ACPI_TYPE_INTBUF &&
 	    (t2 == ACPI_TYPE_INTEGER || t2 == ACPI_TYPE_BUFFER))
@@ -662,8 +662,8 @@ bool fwts_method_type_matches(ACPI_OBJECT_TYPE t1, ACPI_OBJECT_TYPE t2)
 int fwts_method_buffer_size(
 	fwts_framework *fw,
 	const char *name,
-	ACPI_OBJECT *obj,
-	size_t buf_size)
+	const ACPI_OBJECT *obj,
+	const size_t buf_size)
 {
 	if (obj->Buffer.Length != buf_size) {
 		fwts_failed(fw, LOG_LEVEL_CRITICAL,
@@ -903,7 +903,7 @@ void fwts_method_test_reference_return(
 
 /*
  *  fwts_method_test_NULL_return
- *	check if no object was retuned
+ *	check if no object was returned
  */
 void fwts_method_test_NULL_return(
 	fwts_framework *fw,
@@ -1094,7 +1094,7 @@ void fwts_method_test_passed_failed_return(
 			fwts_advice(fw,
 				"Method %s should be returning the correct "
 				"0 or 1 return values. "
-				"Unexpected behaviour may occur becauses of "
+				"Unexpected behaviour may occur because of "
 				"this error, the AML code does not conform to "
 				"the ACPI specification and should be fixed.",
 				method);
@@ -1176,7 +1176,7 @@ void fwts_evaluate_found_method(
 }
 
 int fwts_evaluate_method(fwts_framework *fw,
-	uint32_t test_type,  /* Manditory or optional */
+	const uint32_t test_type,  /* Manditory or optional */
 	ACPI_HANDLE *parent,
 	char *name,
 	ACPI_OBJECT *args,
@@ -1210,7 +1210,7 @@ int fwts_evaluate_method(fwts_framework *fw,
 	return FWTS_OK;
 }
 
-bool fwts_method_valid_HID_string(char *str)
+bool fwts_method_valid_HID_string(const char *str)
 {
 	if (strlen(str) == 7) {
 		/* PNP ID, must be 3 capitals followed by 4 hex */
@@ -1240,7 +1240,10 @@ bool fwts_method_valid_HID_string(char *str)
 	return false;
 }
 
-bool fwts_method_valid_EISA_ID(uint32_t id, char *buf, size_t buf_len)
+bool fwts_method_valid_EISA_ID(
+	const uint32_t id,
+	char *buf,
+	const size_t buf_len)
 {
 	snprintf(buf, buf_len, "%c%c%c%02" PRIX32 "%02" PRIX32,
 		0x40 + ((id >> 2) & 0x1f),
@@ -1557,7 +1560,7 @@ static void method_test_CRS_mif_maf(
 	if (len == 0) {
 		if ((mif == 1) && (maf == 1)) {
 			snprintf(tmp, sizeof(tmp), "Method%s%sMifMafBothOne", objname, tag);
-			if (fw->flags & FWTS_FLAG_TEST_SBBR)
+			if (fw->flags & FWTS_FLAG_SBBR)
 				fwts_warning(fw, tmp,
 					"%s %s _MIF and _MAF flags are both "
 					"set to one which is invalid when "
@@ -1586,7 +1589,7 @@ static void method_test_CRS_mif_maf(
 				*passed = false;
 			} else if (min % tmpgran != 0) {
 				snprintf(tmp, sizeof(tmp), "Method%s%sMinNotMultipleOfGran", objname, tag);
-				if (fw->flags & FWTS_FLAG_TEST_SBBR)
+				if (fw->flags & FWTS_FLAG_SBBR)
 					fwts_warning(fw, tmp,
 						"%s %s _MIN address is not a multiple "
 						"of the granularity when _MIF is 1.",
@@ -1613,7 +1616,7 @@ static void method_test_CRS_mif_maf(
 				*passed = false;
 			} else if (max % tmpgran != 0) {
 				snprintf(tmp, sizeof(tmp), "Method%s%sMaxNotMultipleOfGran", objname, tag);
-				if (fw->flags & FWTS_FLAG_TEST_SBBR)
+				if (fw->flags & FWTS_FLAG_SBBR)
 					fwts_warning(fw, tmp,
 						"%s %s _MAX address is not a multiple "
 						"of the granularity when _MAF is 1.",
@@ -1632,7 +1635,7 @@ static void method_test_CRS_mif_maf(
 		if ((mif == 0) && (maf == 0) &&
 		    (len % (granularity + 1) != 0)) {
 			snprintf(tmp, sizeof(tmp), "Method%s%sLenNotMultipleOfGran", objname, tag);
-			if (fw->flags & FWTS_FLAG_TEST_SBBR)
+			if (fw->flags & FWTS_FLAG_SBBR)
 				fwts_warning(fw, tmp,
 					"%s %s length is not a multiple "
 					"of the granularity when _MIF "
@@ -1650,7 +1653,7 @@ static void method_test_CRS_mif_maf(
 		}
 		if (((mif == 0) && (maf == 1)) || ((mif == 1) && (maf == 0))) {
 			snprintf(tmp, sizeof(tmp), "Method%s%sMifMafInvalid", objname, tag);
-			if (fw->flags & FWTS_FLAG_TEST_SBBR)
+			if (fw->flags & FWTS_FLAG_SBBR)
 				fwts_warning(fw, tmp,
 					"%s %s _MIF and _MAF flags are either "
 					"0 and 1 or 1 and 0 which is invalid when "
@@ -1669,7 +1672,7 @@ static void method_test_CRS_mif_maf(
 		if ((mif == 1) && (maf == 1)) {
 			if (granularity != 0) {
 				snprintf(tmp, sizeof(tmp), "Method%s%sGranularityNotZero", objname, tag);
-				if (fw->flags & FWTS_FLAG_TEST_SBBR)
+				if (fw->flags & FWTS_FLAG_SBBR)
 					fwts_warning(fw, tmp,
 						"%s %s granularity 0x%" PRIx64
 						" is not zero as expected when "
@@ -1687,7 +1690,7 @@ static void method_test_CRS_mif_maf(
 			}
 			if (min > max) {
 				snprintf(tmp, sizeof(tmp), "Method%s%sMaxLessThanMin", objname, tag);
-				if (fw->flags & FWTS_FLAG_TEST_SBBR)
+				if (fw->flags & FWTS_FLAG_SBBR)
 					fwts_warning(fw, tmp,
 						"%s %s minimum address range 0x%" PRIx64
 						" is greater than the maximum address "
@@ -1705,7 +1708,7 @@ static void method_test_CRS_mif_maf(
 			}
 			if (max - min + 1 != len) {
 				snprintf(tmp, sizeof(tmp), "Method%s%sLengthInvalid", objname, tag);
-				if (fw->flags & FWTS_FLAG_TEST_SBBR)
+				if (fw->flags & FWTS_FLAG_SBBR)
 					fwts_warning(fw, tmp,
 						"%s %s length 0x%" PRIx64
 						" does not match the difference between "
@@ -1755,7 +1758,7 @@ void fwts_method_test_CRS_large_resource_items(
 		"WORD Address Space Descriptor",
 		"Extended IRQ Descriptor",
 		"QWORD Address Space Descriptor",
-		"Extended Addresss Space Descriptor",
+		"Extended Address Space Descriptor",
 		"GPIO Connection Descriptor",
 		"Reserved",
 		"Generic Serial Bus Connection Descriptor",
@@ -1954,9 +1957,9 @@ void fwts_method_test_CRS_large_resource_items(
 		fwts_method_test_CRS_large_size(fw, name, objname, data, length, 17, 65535, passed);
 		if (!*passed)	/* Too short, abort */
 			break;
-		fwts_acpi_reserved_bits_check("_CRS", "Flags[low]", data[4], 1, 7, passed);
-		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
-		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
+		fwts_acpi_reserved_bits("_CRS", "Flags[low]", data[4], 1, 7, passed);
+		fwts_acpi_reserved_zero("_CRS", "Flags[high]", data[5], passed);
+		fwts_acpi_reserved_zero("_CRS", "Flags[high]", data[5], passed);
 		break;
 	case 0xe: /* 6.4.3.8.2 Serial Bus Connection Descriptors */
 		fwts_method_test_CRS_large_size(fw, name, objname, data, length, 11, 65535, passed);
@@ -1967,8 +1970,8 @@ void fwts_method_test_CRS_large_resource_items(
 		if (!*passed)	/* Too short, abort */
 			break;
 
-		fwts_acpi_reserved_bits_check("_CRS", "Flags[low]", data[4], 2, 7, passed);
-		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
+		fwts_acpi_reserved_bits("_CRS", "Flags[low]", data[4], 2, 7, passed);
+		fwts_acpi_reserved_zero("_CRS", "Flags[high]", data[5], passed);
 
 		if (data[6] > 0xd && data[6] < 0x80) {
 			*passed = false;
@@ -1983,15 +1986,15 @@ void fwts_method_test_CRS_large_resource_items(
 				"section 6.4.3.10 of the ACPI spec.");
 		}
 
-		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
+		fwts_acpi_reserved_zero("_CRS", "Flags[high]", data[5], passed);
 		break;
 	case 0x10: /* 6.4.3.11 Pin Group Descriptors */
 		fwts_method_test_CRS_large_size(fw, name, objname, data, length, 13, 65535, passed);
 		if (!*passed)	/* Too short, abort */
 			break;
 
-		fwts_acpi_reserved_bits_check("_CRS", "Flags[low]", data[4], 1, 7, passed);
-		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
+		fwts_acpi_reserved_bits("_CRS", "Flags[low]", data[4], 1, 7, passed);
+		fwts_acpi_reserved_zero("_CRS", "Flags[high]", data[5], passed);
 
 		break;
 	case 0x11: /* 6.4.3.12 Pin Group Function Descriptors */
@@ -1999,17 +2002,17 @@ void fwts_method_test_CRS_large_resource_items(
 		if (!*passed)	/* Too short, abort */
 			break;
 
-		fwts_acpi_reserved_bits_check("_CRS", "Flags[low]", data[4], 2, 7, passed);
-		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
-		fwts_acpi_reserved_zero_check("_CRS", "Resource Source Index", data[8], passed);
+		fwts_acpi_reserved_bits("_CRS", "Flags[low]", data[4], 2, 7, passed);
+		fwts_acpi_reserved_zero("_CRS", "Flags[high]", data[5], passed);
+		fwts_acpi_reserved_zero("_CRS", "Resource Source Index", data[8], passed);
 		break;
 	case 0x12: /* 6.4.3.13 Pin Group Configuration Descriptor */
 		fwts_method_test_CRS_large_size(fw, name, objname, data, length, 19, 65535, passed);
 		if (!*passed)	/* Too short, abort */
 			break;
 
-		fwts_acpi_reserved_bits_check("_CRS", "Flags[low]", data[4], 2, 7, passed);
-		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
+		fwts_acpi_reserved_bits("_CRS", "Flags[low]", data[4], 2, 7, passed);
+		fwts_acpi_reserved_zero("_CRS", "Flags[high]", data[5], passed);
 
 		if (data[6] > 0xd && data[6] < 0x80) {
 			*passed = false;
@@ -2024,7 +2027,7 @@ void fwts_method_test_CRS_large_resource_items(
 				"section 6.4.3.10 of the ACPI spec.");
 		}
 
-		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
+		fwts_acpi_reserved_zero("_CRS", "Flags[high]", data[5], passed);
 		break;
 	default:
 		snprintf(tmp, sizeof(tmp), "Method%sUnkownLargeResourceItem", objname);
@@ -2436,10 +2439,10 @@ void fwts_method_test_BMD_return(
 	if (fwts_method_package_elements_all_type(fw, name, obj, ACPI_TYPE_INTEGER) != FWTS_OK)
 		return;
 
-	fwts_acpi_reserved_bits_check("_BMD", "Status Flags",
+	fwts_acpi_reserved_bits("_BMD", "Status Flags",
 		obj->Package.Elements[0].Integer.Value, 7, 31, &failed);
 
-	fwts_acpi_reserved_bits_check("_BMD", "Capability Flags",
+	fwts_acpi_reserved_bits("_BMD", "Capability Flags",
 		obj->Package.Elements[1].Integer.Value, 6, 31, &failed);
 
 	if (!failed)
@@ -2501,7 +2504,7 @@ void fwts_method_test_NBS_return(
 	ret = (nbs_return_t *) obj->Buffer.Pointer;
 	check_nvdimm_status(fw, name, ret->status, &passed);
 	check_nvdimm_extended_status(fw, name, ret->extended_status, 0, &passed);
-	fwts_acpi_reserved_bits_check("_NBS", "Validation Flags",
+	fwts_acpi_reserved_bits("_NBS", "Validation Flags",
 		ret->validation_flags, 1, 15, &passed);
 
 	if (passed)
@@ -2529,18 +2532,18 @@ void fwts_method_test_NCH_return(
 	ret = (nch_return_t *) obj->Buffer.Pointer;
 	check_nvdimm_status(fw, name, ret->status, &passed);
 	check_nvdimm_extended_status(fw, name, ret->extended_status, 0, &passed);
-	fwts_acpi_reserved_bits_check("_NCH", "Validation Flags",
+	fwts_acpi_reserved_bits("_NCH", "Validation Flags",
 		ret->extended_status, 2, 15, &passed);
 
 	/* Health Status Flags [2..7], [11.15], [19..31] are reserved */
-	fwts_acpi_reserved_bits_check("_NCH", "Health Status Flags",
+	fwts_acpi_reserved_bits("_NCH", "Health Status Flags",
 		ret->health_status_flags, 2, 7, &passed);
-	fwts_acpi_reserved_bits_check("_NCH", "Health Status Flags",
+	fwts_acpi_reserved_bits("_NCH", "Health Status Flags",
 		ret->health_status_flags, 11, 15, &passed);
-	fwts_acpi_reserved_bits_check("_NCH", "Health Status Flags",
+	fwts_acpi_reserved_bits("_NCH", "Health Status Flags",
 		ret->health_status_flags, 19, 31, &passed);
 
-	fwts_acpi_reserved_bits_check("_NCH", "Health Status Attributes",
+	fwts_acpi_reserved_bits("_NCH", "Health Status Attributes",
 		ret->health_status_attributes, 1, 31, &passed);
 
 	if (passed)
@@ -2570,14 +2573,14 @@ void fwts_method_test_NIC_return(
 	check_nvdimm_extended_status(fw, name, ret->extended_status, 0, &passed);
 
 	/* Health Error Injection Capabilities [2..7], [11.15], [19..31] are reserved */
-	fwts_acpi_reserved_bits_check("_NIC", "Health Error Injection Capabilities",
+	fwts_acpi_reserved_bits("_NIC", "Health Error Injection Capabilities",
 		ret->health_error_injection, 2, 7, &passed);
-	fwts_acpi_reserved_bits_check("_NIC", "Health Error Injection Capabilities",
+	fwts_acpi_reserved_bits("_NIC", "Health Error Injection Capabilities",
 		ret->health_error_injection, 11, 15, &passed);
-	fwts_acpi_reserved_bits_check("_NIC", "Health Error Injection Capabilities",
+	fwts_acpi_reserved_bits("_NIC", "Health Error Injection Capabilities",
 		ret->health_error_injection, 19, 31, &passed);
 
-	fwts_acpi_reserved_bits_check("_NIC", "Health Status Attributes Capabilities",
+	fwts_acpi_reserved_bits("_NIC", "Health Status Attributes Capabilities",
 		ret->health_status_attributes, 1, 31, &passed);
 
 	if (passed)
@@ -2631,18 +2634,18 @@ void fwts_method_test_NIG_return(
 	ret = (nig_return_t *) obj->Buffer.Pointer;
 	check_nvdimm_status(fw, name, ret->status, &passed);
 	check_nvdimm_extended_status(fw, name,  ret->extended_status, 0, &passed);
-	fwts_acpi_reserved_bits_check("_NIG", "Validation Flags",
+	fwts_acpi_reserved_bits("_NIG", "Validation Flags",
 		ret->validation_flags, 2, 15, &passed);
 
 	/* Injected Health Status Errors [2..7], [11.15], [19..31] are reserved */
-	fwts_acpi_reserved_bits_check("_NIG", "Injected Health Status Errors",
+	fwts_acpi_reserved_bits("_NIG", "Injected Health Status Errors",
 		ret->health_status_errors, 2, 7, &passed);
-	fwts_acpi_reserved_bits_check("_NIG", "Injected Health Status Errors",
+	fwts_acpi_reserved_bits("_NIG", "Injected Health Status Errors",
 		ret->health_status_errors, 11, 15, &passed);
-	fwts_acpi_reserved_bits_check("_NIG", "Injected Health Status Errors",
+	fwts_acpi_reserved_bits("_NIG", "Injected Health Status Errors",
 		ret->health_status_errors, 19, 31, &passed);
 
-	fwts_acpi_reserved_bits_check("_NIG", "Health Status Attributes of Injected Errors",
+	fwts_acpi_reserved_bits("_NIG", "Health Status Attributes of Injected Errors",
 		ret->health_status_attributes, 1, 31, &passed);
 
 	if (passed)
@@ -2670,7 +2673,7 @@ void fwts_method_test_STA_return(
 			"but not present, which is impossible.", name);
 		passed = false;
 	}
-	fwts_acpi_reserved_bits_check("_STA", "Reserved Bits", obj->Integer.Value, 5, 31, &passed);
+	fwts_acpi_reserved_bits("_STA", "Reserved Bits", obj->Integer.Value, 5, 31, &passed);
 
 	if (passed)
 		fwts_method_passed_sane_uint64(fw, name, obj->Integer.Value);
@@ -3033,7 +3036,7 @@ void fwts_method_test_BST_return(
 
 	/* Sanity check each field */
 	/* Battery State */
-	fwts_acpi_reserved_bits_check("_BST", "Battery State",
+	fwts_acpi_reserved_bits("_BST", "Battery State",
 			obj->Package.Elements[0].Integer.Value, 3, 31, &failed);
 	/* Ensure bits 0 (discharging) and 1 (charging) are not both set, see 10.2.2.6 */
 	if (((obj->Package.Elements[0].Integer.Value) & 3) == 3) {
@@ -3086,7 +3089,7 @@ void fwts_method_test_BPC_return(
 	if (fwts_method_test_revision(fw, name, obj->Package.Elements[0].Integer.Value, 1) != FWTS_OK)
 		passed = false;
 
-	fwts_acpi_reserved_bits_check("_BPC", "Power Threshold Support Capability",
+	fwts_acpi_reserved_bits("_BPC", "Power Threshold Support Capability",
 		obj->Package.Elements[1].Integer.Value, 2, 31, &passed);
 
 	if (!passed)
@@ -3130,5 +3133,3 @@ void fwts_method_test_BPS_return(
 		else
 			fwts_method_passed_sane(fw, name, "package");
 }
-
-#endif
