@@ -37,8 +37,6 @@
 
 #include "fwts_acpi_object_eval.h"
 
-#if defined(FWTS_HAS_ACPI)
-
 #define BIOS_START	(0x000e0000)		/* Start of BIOS memory */
 #define BIOS_END  	(0x000fffff)		/* End of BIOS memory */
 #define BIOS_LENGTH	(BIOS_END - BIOS_START)	/* Length of BIOS memory */
@@ -263,7 +261,7 @@ static void fwts_acpi_add_table(
 		if (strncmp(tables[i].name, name, 4) == 0)
 			which++;
 		if (tables[i].data == NULL) {
-			strncpy(tables[i].name, name, 4);
+			memcpy(tables[i].name, name, 4);
 			tables[i].name[4] = 0;
 			tables[i].data = table;
 			tables[i].addr = addr;
@@ -302,7 +300,7 @@ int fwts_acpi_free_tables(void)
  */
 fwts_bool fwts_acpi_is_reduced_hardware(fwts_framework *fw)
 {
-	fwts_acpi_table_info *table;
+	fwts_acpi_table_info *table = NULL;
 	const fwts_acpi_table_fadt *fadt;
 
 	if (fwts_acpi_find_table(fw, "FACP", 0, &table) != FWTS_OK) {
@@ -317,7 +315,7 @@ fwts_bool fwts_acpi_is_reduced_hardware(fwts_framework *fw)
 
 	if ((fadt->header.revision >= 5) &&
 			(fadt->header.length >= 116) &&
-			(fadt->flags & FWTS_ACPI_FADT_FLAGS_HW_REDUCED_ACPI)) {
+			(fadt->flags & FWTS_FADT_FLAGS_HW_REDUCED_ACPI)) {
 		return FWTS_TRUE;
 	}
 	return FWTS_FALSE;
@@ -971,7 +969,7 @@ void fwts_acpi_fixup_addr_from_fadt(
 	uint32_t addr32,
 	uint64_t addr64)
 {
-	fwts_acpi_table_info *table;
+	fwts_acpi_table_info *table = NULL;
 
 	/* Fetch the table */
 	if (fwts_acpi_find_table(fw, name, 0, &table) != FWTS_OK)
@@ -1001,7 +999,7 @@ static int fwts_acpi_load_tables_fixup(fwts_framework *fw)
 {
 	int i, j, count;
 	char *oem_tbl_id;
-	fwts_acpi_table_info *table;
+	fwts_acpi_table_info *table = NULL;
 	fwts_acpi_table_rsdp *rsdp = NULL;
 	fwts_acpi_table_fadt *fadt = NULL;
 	uint64_t rsdt_fake_addr = 0, xsdt_fake_addr = 0;
@@ -1030,8 +1028,11 @@ static int fwts_acpi_load_tables_fixup(fwts_framework *fw)
 		uint64_t facs_addr;
 		fwts_acpi_table_facs *facs = NULL;
 
-		/* This is most unexpected, so warn about it */
-		fwts_log_warning(fw, "No FACS found, fwts has faked one instead.");
+		if (fwts_acpi_is_reduced_hardware(fw))	/* FACS is optional on reduced hardware */
+			fwts_log_info(fw, "No FACS found, fwts has faked one instead.");
+		else	/* This is most unexpected, so warn about it */
+			fwts_log_warning(fw, "No FACS found, fwts has faked one instead.");
+
 		if ((facs = fwts_low_calloc(1, size)) == NULL) {
 			fwts_log_error(fw, "Cannot allocate fake FACS.");
 			return FWTS_ERROR;
@@ -1413,6 +1414,7 @@ bool fwts_acpi_obj_find(fwts_framework *fw, const char *obj_name)
 	/* Search for object */
 	fwts_list_foreach(item, objects) {
 		char *name = fwts_list_data(char*, item);
+
 		if (strcmp(expanded, name) == 0) {
 			found = true;
 			break;
@@ -1424,19 +1426,20 @@ bool fwts_acpi_obj_find(fwts_framework *fw, const char *obj_name)
 }
 
 /*
- *  fwts_acpi_reserved_zero_check_()
+ *  fwts_acpi_reserved_zero_()
  *  verify whether the reserved field is zero
  */
-void fwts_acpi_reserved_zero_check_(
+void fwts_acpi_reserved_zero_(
 	fwts_framework *fw,
 	const char *table,
 	const char *field,
-	uint64_t value,
-	uint8_t size,
+	const uint64_t value,
+	const uint8_t size,
 	bool *passed)
 {
 	if (value != 0) {
 		char label[20];
+
 		strncpy(label, table, 4);	/* ACPI table name is 4 char long */
 		strncpy(label + 4, "ReservedNonZero", sizeof(label) - 4);
 
@@ -1467,15 +1470,15 @@ void fwts_acpi_reserved_zero_check_(
 }
 
 /*
- *  fwts_acpi_reserved_zero_array_check()
+ *  fwts_acpi_reserved_zero_array()
  *  verify whether the reserved array is all zeroed
  */
-void fwts_acpi_reserved_zero_array_check(
+void fwts_acpi_reserved_zero_array(
 	fwts_framework *fw,
 	const char *table,
 	const char *field,
-	uint8_t* data,
-	uint8_t length,
+	const uint8_t* data,
+	const uint8_t length,
 	bool *passed)
 {
 	uint32_t value = 0;
@@ -1500,16 +1503,16 @@ void fwts_acpi_reserved_zero_array_check(
 }
 
 /*
- *  fwts_acpi_fixed_value_check()
+ *  fwts_acpi_fixed_value()
  *  verify whether a field matches the designed fixed value
  */
-void fwts_acpi_fixed_value_check(
+void fwts_acpi_fixed_value(
 	fwts_framework *fw,
-	fwts_log_level level,
+	const fwts_log_level level,
 	const char *table,
 	const char *field,
-	uint8_t actual,
-	uint8_t must_be,
+	const uint8_t actual,
+	const uint8_t must_be,
 	bool *passed)
 {
 	char label[20];
@@ -1526,17 +1529,17 @@ void fwts_acpi_fixed_value_check(
 }
 
 /*
- *  fwts_acpi_reserved_bits_check_()
+ *  fwts_acpi_reserved_bits_()
  *  verify whether the reserved bits are zero
  */
-void fwts_acpi_reserved_bits_check_(
+void fwts_acpi_reserved_bits_(
 	fwts_framework *fw,
 	const char *table,
 	const char *field,
-	uint64_t value,
-	uint8_t size,
-	uint8_t min,
-	uint8_t max,
+	const uint64_t value,
+	const uint8_t size,
+	const uint8_t min,
+	const uint8_t max,
 	bool *passed)
 {
 	uint64_t mask = 0;
@@ -1578,19 +1581,20 @@ void fwts_acpi_reserved_bits_check_(
 }
 
 /*
- *  fwts_acpi_reserved_type_check()
+ *  fwts_acpi_reserved_type()
  *  verify whether the reserved types are used
  */
-void fwts_acpi_reserved_type_check(
+void fwts_acpi_reserved_type(
 	fwts_framework *fw,
 	const char *table,
-	uint8_t value,
-	uint8_t min,
-	uint8_t reserved,
+	const uint8_t value,
+	const uint8_t min,
+	const uint8_t reserved,
 	bool *passed)
 {
 	if (value < min || value >= reserved) {
 		char label[20];
+
 		strncpy(label, table, 4);	/* ACPI name is 4 char long */
 		strncpy(label + 4, "BadSubTableType", sizeof(label) - 4);
 
@@ -1604,45 +1608,49 @@ void fwts_acpi_reserved_type_check(
 }
 
 /*
- *  Space Id defined for Generic Address Structure (GAS)
- *  See Table 5.1: Generic Address Structure (GAS) in ACPI spec
- *  Also see fwts_acpi.h
+ *  get_space_id_name()
+ *  convert Generic Address Structure to a string, NULL if undefined
  */
-static const char *gas_space_id_names[] = {
-	"System Memory (0x0)",
-	"System I/O (0x1)",
-	"PCI Configuration (0x2)",
-	"Embedded Controller (0x3)",
-	"SMBus (0x4)",
-	"SystemCMOS (0x5)",
-	"PciBarTarget (0x6)",
-	"IPMI (0x7)",
-	"General PurposeIO (0x8)",
-	"GenericSerialBus (0x9)",
-	"Platform Communications Channel (0xa)",
-	"Functional Fixed Hardware (0x7f)",
-};
+static const char *get_space_id_name(const uint8_t id)
+{
+	/*
+	 *  Space Id defined for Generic Address Structure (GAS)
+	 *  See Table 5.1: Generic Address Structure (GAS) in ACPI spec
+	 *  Also see fwts_acpi.h
+	 */
+	static const char *gas_space_id_names[] = {
+		"System Memory (0x0)",
+		"System I/O (0x1)",
+		"PCI Configuration (0x2)",
+		"Embedded Controller (0x3)",
+		"SMBus (0x4)",
+		"SystemCMOS (0x5)",
+		"PciBarTarget (0x6)",
+		"IPMI (0x7)",
+		"General PurposeIO (0x8)",
+		"GenericSerialBus (0x9)",
+		"Platform Communications Channel (0xa)"
+	};
 
-static const char *get_space_id_name(uint8_t id) {
-	if (id <= 0x0a)
+	if (id < FWTS_ARRAY_SIZE(gas_space_id_names))
 		return gas_space_id_names[id];
 	else if (id == 0x7f)
-		return gas_space_id_names[0x0b];
+		return "Functional Fixed Hardware (0x7f)";
 	else
 		return NULL;
 }
 
 /*
- *  fwts_acpi_space_id_check()
+ *  fwts_acpi_space_id()
  *  check whether gas space id matches
  */
-void fwts_acpi_space_id_check(
+void fwts_acpi_space_id(
 	fwts_framework *fw,
 	const char *table,
 	const char *field,
 	bool *passed,
-	uint8_t actual,
-	uint8_t num_type,
+	const uint8_t actual,
+	const uint8_t num_type,
 	...)
 {
 	bool matched = false;
@@ -1692,17 +1700,18 @@ void fwts_acpi_space_id_check(
 }
 
 /*
- *  fwts_acpi_table_length_check()
+ *  fwts_acpi_table_length()
  *  verify whether table length is sane
  */
-bool fwts_acpi_table_length_check(
+bool fwts_acpi_table_length(
 	fwts_framework *fw,
 	const char *table,
-	uint32_t length,
-	uint32_t size)
+	const uint32_t length,
+	const uint32_t size)
 {
 	if (length < size) {
 		char label[30];
+
 		strncpy(label, table, 4);	/* ACPI name is 4 char long */
 		strncpy(label + 4, "TooShort", sizeof(label) - 4);
 		fwts_failed(fw, LOG_LEVEL_HIGH, label,
@@ -1715,29 +1724,76 @@ bool fwts_acpi_table_length_check(
 }
 
 /*
- *  fwts_acpi_structure_length_check()
+ *  fwts_acpi_structure_length()
  *  verify whether sub structure length is sane
  */
-bool fwts_acpi_structure_length_check(
+bool fwts_acpi_structure_length(
 	fwts_framework *fw,
 	const char *table,
-	uint8_t type,
-	uint32_t length,
-	uint32_t size)
+	const uint8_t type,
+	const uint32_t actual_length,
+	const uint32_t struct_length)
 {
-	if (length != size) {
+	if (actual_length != struct_length) {
 		char label[30];
+
 		strncpy(label, table, 4);	/* ACPI name is 4 char long */
 		strncpy(label + 4, "BadStructureLength", sizeof(label) - 4);
 		fwts_failed(fw, LOG_LEVEL_CRITICAL, label,
 			"%4.4s structure Type 0x%2.2" PRIx8 " should have "
 			"length 0x%2.2" PRIx8 ", got 0x%2.2" PRIx8,
-			table, type, length, size);
+			table, type, struct_length, actual_length);
 		return false;
 	}
 	return true;
 }
 
+/*
+ *  fwts_acpi_structure_length_zero()
+ *  verify whether sub structure length is zero
+ */
+bool fwts_acpi_structure_length_zero(
+	fwts_framework *fw,
+	const char *table,
+	const uint16_t length,
+	const uint32_t offset)
+{
+	if (length == 0) {
+		char label[30];
+
+		strncpy(label, table, 4);	/* ACPI name is 4 char long */
+		strncpy(label + 4, "StructLengthZero", sizeof(label) - 4);
+		fwts_failed(fw, LOG_LEVEL_CRITICAL, label,
+			"%4.4s structure (offset 0x%4.4" PRIx32 ") "
+			"length cannot be 0", table, offset);
+		return true;
+	}
+	return false;
+}
+
+/*
+ *  fwts_acpi_structure_range()
+ *  verify whether sub structure is out of table range
+ */
+bool fwts_acpi_structure_range(
+	fwts_framework *fw,
+	const char *table,
+	const uint32_t table_length,
+	const uint32_t offset)
+{
+	if (offset > table_length) {
+		char label[30];
+
+		strncpy(label, table, 4);	/* ACPI name is 4 char long */
+		strncpy(label + 4, "BadTableLength", sizeof(label) - 4);
+		fwts_failed(fw, LOG_LEVEL_CRITICAL, label,
+			"%4.4s has more subtypes than its size can handle", table);
+
+		return true;
+	}
+	return false;
+}
+
 static uint32_t acpi_version;
 /*
  *  fwts_get_acpi_version()
@@ -1774,4 +1830,16 @@ uint32_t fwts_get_acpi_version(fwts_framework *fw)
 	return acpi_version;
 }
 
-#endif
+/*
+ *  fwts_get_fadt_version()
+ * 	get fadt major and minor versions
+ */
+void fwts_get_fadt_version(fwts_framework *fw, uint8_t *major, uint8_t *minor)
+{
+	uint32_t acpi_version;
+
+	/* ACPI version = FADT major & minor versions */
+	acpi_version = fwts_get_acpi_version(fw);
+	*major = (acpi_version & 0xF00) >> 8;
+	*minor = (acpi_version & 0xFF) >> 4;
+}
