@@ -36,7 +36,7 @@ static char *module_name = NULL;
  */
 static int check_module_loaded_no_dev(
 	fwts_framework *fw,
-	char *module)
+	const char *module)
 {
 	bool loaded;
 
@@ -179,7 +179,7 @@ int fwts_lib_efi_runtime_open(void)
  *  fwts_lib_efi_runtime_close()
  *	close the device
  */
-int fwts_lib_efi_runtime_close(int fd)
+int fwts_lib_efi_runtime_close(const int fd)
 {
 	return close(fd);
 }
@@ -214,7 +214,7 @@ int fwts_lib_efi_runtime_kernel_lockdown(fwts_framework *fw)
 int fwts_lib_efi_runtime_module_init(fwts_framework *fw, int *fd)
 {
 
-	if (fwts_firmware_detect() != FWTS_FIRMWARE_UEFI) {
+	if (fw->firmware_type != FWTS_FIRMWARE_UEFI) {
 		fwts_log_info(fw, "Cannot detect any UEFI firmware. Aborted.");
 		return FWTS_ABORTED;
 	}
