@@ -29,8 +29,6 @@
 
 #include "fwts.h"
 
-#if defined(FWTS_HAS_ACPI)
-
 #include "fwts_iasl_interface.h"
 #include "fwts_acpica.h"
 
@@ -319,5 +317,3 @@ const char *fwts_iasl_exception_level(uint8_t level)
 {
 	return fwts_iasl_exception_level__(level);
 }
-
-#endif
