@@ -147,7 +147,7 @@ static int fwts_uefi_get_interface(char **path)
 
 /*
  *  fwts_uefi_str_to_str16()
- *	convert 8 bit C string to 16 bit sring.
+ *	convert 8 bit C string to 16 bit string.
  */
 void fwts_uefi_str_to_str16(uint16_t *dst, const size_t len, const char *src)
 {
@@ -550,17 +550,13 @@ bool fwts_uefi_efivars_iface_exist(void)
  *	this bitmask can be read via an IOCTL call. Before Linux 5.11 the value
  *	cannot be determined.
  */
-void fwts_uefi_rt_support_status_get(int fd, bool *have_rtsupported, uint32_t *rtservicessupported)
+void fwts_uefi_rt_support_status_get(int fd, uint32_t *rtservicessupported)
 {
 	long ioret;
 
 	ioret = ioctl(fd, EFI_RUNTIME_GET_SUPPORTED_MASK, rtservicessupported);
-	if (ioret == -1) {
-		*have_rtsupported = false;
+	if (ioret == -1)
 		*rtservicessupported = EFI_RT_SUPPORTED_ALL;
-	} else {
-		*have_rtsupported = true;
-	}
 
 	return;
 }
