@@ -43,7 +43,7 @@ static int get_dimm_property(
 
 		if (node >= 0) {
 			const char *prop_buf;
-			int prop_len;
+			int prop_len = 0;
 
 			prop_buf = fdt_getprop(fw->fdt, node,
 					property,
@@ -137,7 +137,7 @@ static int process_dimm(
 	char *my_dir)
 {
 	int count, i, failures = 0;
-	struct dirent **namelist;
+	struct dirent **namelist = NULL;
 	bool found = false;
 
 	count = scandir(my_dir, &namelist, NULL, alphasort);
@@ -171,6 +171,8 @@ static int process_dimm(
 		}
 
 		if (strstr(my_buffer, my_string)) {
+			char my_prop_string[15];
+
 			found = true;
 			if (asprintf(&my_path,
 				"%s/%s",
@@ -190,7 +192,6 @@ static int process_dimm(
 				continue;
 			}
 
-			char my_prop_string[15];
 			strcpy(my_prop_string, "/memory-buffer");
 			if (check_status_property_okay(fw, my_path,
 						my_prop_string,
@@ -221,7 +222,7 @@ static int process_dimm(
 					failures++;
 				}
 			}
-
+			free(my_path);
 			free(my_buffer);
 			free(namelist[i]);
 		}
@@ -308,6 +309,7 @@ static int process_mba(
 			if (process_dimm(fw, "dimm", my_path)) {
 				failures++;
 			}
+			free(my_path);
 			free(my_buffer);
 			free(namelist[i]);
 		}
@@ -337,7 +339,7 @@ static int process_mba(
 static int get_linux_mem_devices(fwts_framework *fw)
 {
 	int count, i, failures = 0;
-	struct dirent **namelist;
+	struct dirent **namelist = NULL;
 	bool found = false;
 
 	count = scandir(DT_FS_PATH, &namelist, NULL, alphasort);
@@ -363,6 +365,7 @@ static int get_linux_mem_devices(fwts_framework *fw)
 
 		dirent = namelist[i];
 
+		mem_buffer = NULL;
 		if (dirent->d_name[0] == '.' ||
 			asprintf(&mem_buffer,
 				"%s",
@@ -395,6 +398,7 @@ static int get_linux_mem_devices(fwts_framework *fw)
 			if (process_mba(fw, "mba", mba_path)) {
 				failures++;
 			}
+			free(mba_path);
 			free(mem_buffer);
 			free(namelist[i]);
 		}
