@@ -105,7 +105,7 @@ static char *make_message(const char *fmt, ...)
 
 static int reserv_mem_init(fwts_framework *fw)
 {
-	if (fwts_firmware_detect() != FWTS_FIRMWARE_OPAL) {
+	if (fw->firmware_type != FWTS_FIRMWARE_OPAL) {
 		fwts_skipped(fw,
 			"The firmware type detected was non OPAL "
 			"so skipping the OPAL Reserve Memory DT checks.");
@@ -128,7 +128,7 @@ static int reserv_mem_limits_test(fwts_framework *fw)
 	const char *region_names;
 	const uint64_t *ranges;
 	reserve_region_t *regions;
-	int  offset, len, nr_regions, rc, j;
+	int  offset, len = 0, nr_regions, rc, j;
 	plat_config_t configstruct = {0, 0, 0};
 
 	get_config(fw, CONFIG_FILENAME, &configstruct);
