@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2006, Intel Corporation
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This file was original part of the Linux-ready Firmware Developer Kit
  *
@@ -63,6 +63,7 @@ static int maxreadreq_test1(fwts_framework *fw)
 		int fd;
 		ssize_t n;
 		uint8_t offset = 0;
+		uint16_t vendor_id;
 
 		if (entry->d_name[0] == '.')
 			continue;
@@ -97,6 +98,12 @@ static int maxreadreq_test1(fwts_framework *fw)
 		    (config[FWTS_PCI_CONFIG_SUBCLASS] == FWTS_PCI_SUBCLASS_CODE_AUDIO_DEVICE))
 			continue;
 
+		/* Ignore Intel's Video Device */
+		vendor_id = config[FWTS_PCI_CONFIG_VENDOR_ID] + ((config[FWTS_PCI_CONFIG_VENDOR_ID  + 1]) << 8);
+		if ((config[FWTS_PCI_CONFIG_CLASS_CODE] == FWTS_PCI_CLASS_CODE_DISPLAY_CONTROLLER) &&
+		    (vendor_id == FWTS_PCI_INTEL_VENDOR_ID))
+			continue;
+
 		/* config region too small, do next */
 		if (n < FWTS_PCI_CONFIG_TYPE0_CAPABILITIES_POINTER)
 			continue;
@@ -138,7 +145,8 @@ static int maxreadreq_test1(fwts_framework *fw)
 			"Express bus. Some drivers (for example the Brocade Fibre Channel driver) "
 			"allow one to override the firmware settings. Where possible, this BIOS "
 			"configuration setting is worth increasing it a little more for better "
-			"performance at a small reduction of bus sharing.");
+			"performance at a small reduction of bus sharing. Note it is safe to "
+			"ignore this failure if the register is hardwired to zero per PCIe spec.");
 	} else
 		fwts_passed(fw, "All devices have MaxReadReq set > 128.");
 
