@@ -195,22 +195,46 @@ static int acpi_table_sbbr_check_test2(fwts_framework *fw)
 	return FWTS_OK;
 }
 
+/* List of mandatory ACPI tables (SBBR 4.2.1) */
+static const char *mandatory_acpi_tables[] = {
+	"RSDP",
+	"XSDT",
+	"FACP",
+	"DSDT", /* SSDT is optional */
+	"APIC", /* MADT */
+	"GTDT",
+	"DBG2",
+	"SPCR",
+	"MCFG",
+	"PPTT",
+	NULL
+};
+
 /* List of ACPI tables recommended by SBBR 4.2.2 */
 static const char *recommended_acpi_tables[] = {
-	"MCFG",
+	/* I/O Topology */
 	"IORT",
+	/* Platform Error Interfaces */
 	"BERT",
 	"EINJ",
 	"ERST",
 	"HEST",
-	"RASF",
-	"SPMI",
+	"SDEI",
+	"AEST",
+	/* NUMA */
 	"SLIT",
 	"SRAT",
-	"CSRT",
-	"ECDT",
-	"MPST",
+	"HMAT",
+	/* Platform Communications Channel (PCC) */
 	"PCCT",
+	/* Platform Debug Trigger */
+	"PDTT",
+	/* NVDIMM Firmware Interface */
+	"NFIT",
+	/* Graphics Resource Table */
+	"BGRT",
+	/* IPMI */
+	"SPMI",
 	NULL
 };
 
@@ -235,6 +259,19 @@ static int acpi_table_sbbr_check_test3(fwts_framework *fw)
 {
 	uint32_t i;
 
+	for (i = 0; mandatory_acpi_tables[i] != NULL; i++) {
+		fwts_acpi_table_info *info;
+
+		info = sbbr_search_acpi_tables(fw, mandatory_acpi_tables[i]);
+		if (info == NULL) {
+			fwts_failed(fw, LOG_LEVEL_CRITICAL, "SBBRTableNotFound",
+				    "SBBR mandatory ACPI table \"%s\" not found.", mandatory_acpi_tables[i]);
+		} else {
+			fwts_passed(fw, "SBBR mandatory ACPI table \"%s\" found.",
+			            mandatory_acpi_tables[i]);
+		}
+	}
+
 	for (i = 0; recommended_acpi_tables[i] != NULL; i++) {
 		fwts_acpi_table_info *info;
 
@@ -253,7 +290,7 @@ static int acpi_table_sbbr_check_test3(fwts_framework *fw)
 static fwts_framework_minor_test acpi_table_sbbr_check_tests[] = {
 	{ acpi_table_sbbr_namespace_check_test1, "Test that processors only exist in the _SB namespace." },
 	{ acpi_table_sbbr_check_test2, "Test DSDT and SSDT tables are implemented." },
-	{ acpi_table_sbbr_check_test3, "Check for recommended ACPI tables." },
+	{ acpi_table_sbbr_check_test3, "Check for mandatory and recommended ACPI tables." },
 	{ NULL, NULL }
 };
 
@@ -262,6 +299,6 @@ static fwts_framework_ops acpi_table_sbbr_check_ops = {
 	.minor_tests = acpi_table_sbbr_check_tests
 };
 
-FWTS_REGISTER("acpi_sbbr", &acpi_table_sbbr_check_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_TEST_SBBR)
+FWTS_REGISTER("acpi_sbbr", &acpi_table_sbbr_check_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_SBBR)
 
 #endif
