@@ -40,7 +40,7 @@
 static int esrt_init(fwts_framework *fw)
 {
 
-	if (fwts_firmware_detect() != FWTS_FIRMWARE_UEFI) {
+	if (fw->firmware_type != FWTS_FIRMWARE_UEFI) {
 		fwts_log_info(fw, "Cannot detect any UEFI firmware. Aborted.");
 		return FWTS_ABORTED;
 	}
@@ -263,6 +263,6 @@ static fwts_framework_ops esrt_ops = {
 	.minor_tests = esrt_tests
 };
 
-FWTS_REGISTER("esrt", &esrt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_TEST_UEFI | FWTS_FLAG_ROOT_PRIV)
+FWTS_REGISTER("esrt", &esrt_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_UEFI | FWTS_FLAG_ROOT_PRIV)
 
 #endif
