@@ -263,7 +263,11 @@ static inline bool check_addr_overflow(
         return (len > ~(uintptr_t)0 - (uintptr_t)var_data_addr);
 }
 
-static bool check_sigdb_presence(uint8_t *var_data, size_t datalen, uint8_t *key, uint32_t key_len)
+static bool check_sigdb_presence(
+	uint8_t *var_data,
+	const size_t datalen,
+	const uint8_t *key,
+	const uint32_t key_len)
 {
 	uint8_t *var_data_addr;
 	EFI_SIGNATURE_LIST siglist;
@@ -609,6 +613,6 @@ static fwts_framework_ops securebootcert_ops = {
 	.minor_tests = securebootcert_tests
 };
 
-FWTS_REGISTER("securebootcert", &securebootcert_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_TEST_UEFI | FWTS_FLAG_UNSAFE | FWTS_FLAG_ROOT_PRIV)
+FWTS_REGISTER("securebootcert", &securebootcert_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_UEFI | FWTS_FLAG_UNSAFE | FWTS_FLAG_ROOT_PRIV)
 
 #endif
