@@ -1523,7 +1523,7 @@ static void uefidump_var(fwts_framework *fw, fwts_uefi_var *var)
 
 static int uefidump_init(fwts_framework *fw)
 {
-	if (fwts_firmware_detect() != FWTS_FIRMWARE_UEFI) {
+	if (fw->firmware_type != FWTS_FIRMWARE_UEFI) {
 		fwts_log_info(fw, "Cannot detect any UEFI firmware. Aborted.");
 		return FWTS_ABORTED;
 	}
