@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2012-2021 Canonical
+ * Copyright (c) 2021, ARM Limited. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,7 +39,6 @@
 static int fd;
 static const uint32_t dayofmonth[12] = { 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
 
-static bool have_rtsupported;
 static uint32_t runtimeservicessupported;
 
 static bool dayvalid(EFI_TIME *Time)
@@ -175,8 +175,7 @@ static int uefirttime_init(fwts_framework *fw)
 	if (fwts_lib_efi_runtime_module_init(fw, &fd) == FWTS_ABORTED)
 		return FWTS_ABORTED;
 
-	fwts_uefi_rt_support_status_get(fd, &have_rtsupported,
-			&runtimeservicessupported);
+	fwts_uefi_rt_support_status_get(fd, &runtimeservicessupported);
 
 	return FWTS_OK;
 }
@@ -201,6 +200,12 @@ static int uefirttime_test1(fwts_framework *fw)
 	EFI_TIME_CAPABILITIES efi_time_cap;
 	uint64_t status = ~0ULL;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_TIME)) {
+		fwts_skipped(fw, "Skipping test, GetTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	gettime.Capabilities = &efi_time_cap;
 	gettime.Time = &efi_time;
 	gettime.status = &status;
@@ -236,6 +241,12 @@ static int uefirttime_test_gettime_invalid(
 	struct efi_gettime gettime;
 	uint64_t status = ~0ULL;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_TIME)) {
+		fwts_skipped(fw, "Skipping test, GetTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	gettime.Capabilities = efi_time_cap;
 	gettime.Time = efi_time;
 	gettime.status = &status;
@@ -288,6 +299,12 @@ static int uefirttime_test4(fwts_framework *fw)
 	EFI_TIME time;
 	EFI_TIME_CAPABILITIES efi_time_cap;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_TIME)) {
+		fwts_skipped(fw, "Skipping test, GetTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	gettime.Capabilities = &efi_time_cap;
 	gettime.Time = &oldtime;
 	gettime.status = &status;
@@ -332,6 +349,12 @@ static int uefirttime_test4(fwts_framework *fw)
 		/* Unspecified timezone, local time */
 		time.TimeZone = 2047;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_TIME)) {
+		fwts_skipped(fw, "Skipping test, SetTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	settime.Time = &time;
 	status = ~0ULL;
 	settime.status = &status;
@@ -395,6 +418,11 @@ static int uefirttime_test4(fwts_framework *fw)
 	    !((oldtime.TimeZone != 0) && (newtime.TimeZone == 0))) {
 		fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetTimeTimezone",
 			"Failed to set timezone with UEFI runtime service.");
+		fwts_advice(fw,
+			"Some system firmware may not support the timezone "
+			"value EFI_UNSPECIFIED_TIMEZONE(2047) and set the "
+			"value 0 directly instead of returning an error which "
+			"causes the failure.");
 		return FWTS_ERROR;
 	}
 
@@ -426,6 +454,12 @@ static int uefirttime_test_settime_invalid(
 	long ioret;
 	static uint64_t status;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_TIME)) {
+		fwts_skipped(fw, "Skipping test, SetTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	status = ~0ULL;
 	settime->status = &status;
 
@@ -462,6 +496,12 @@ static int uefirttime_test_settime_invalid_time(
 	uint64_t status = ~0ULL;
 	int ret, ioret;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_TIME)) {
+		fwts_skipped(fw, "Skipping test, GetTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	gettime.Time = &oldtime;
 	gettime.status = &status;
 	gettime.Capabilities = NULL;
@@ -474,7 +514,7 @@ static int uefirttime_test_settime_invalid_time(
 			return FWTS_SKIP;
 		}
 		fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetTime",
-			"Failed to get wakeup time with UEFI runtime service.");
+			"Failed to get time with UEFI runtime service.");
 		fwts_uefi_print_status_info(fw, status);
 		return FWTS_ERROR;
 	}
@@ -502,6 +542,9 @@ static int uefirttime_test_settime_invalid_time(
 
 	ret = uefirttime_test_settime_invalid(fw, &settime);
 
+	if (ret == FWTS_SKIP)
+		return ret;
+
 	/* Restore original time */
 	settime.Time = &oldtime;
 	status = ~0ULL;
@@ -514,7 +557,7 @@ static int uefirttime_test_settime_invalid_time(
 			return FWTS_SKIP;
 		}
 		fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetTime",
-			"Failed to set wakeup time with UEFI runtime service.");
+			"Failed to set time with UEFI runtime service.");
 		fwts_uefi_print_status_info(fw, status);
 		return FWTS_ERROR;
 	}
@@ -656,6 +699,12 @@ static int uefirttime_test18(fwts_framework *fw)
 	uint8_t enabled, pending;
 	EFI_TIME efi_time;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_WAKEUP_TIME)) {
+		fwts_skipped(fw, "Skipping test, GetWakeupTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	getwakeuptime.Enabled = &enabled;
 	getwakeuptime.Pending = &pending;
 	getwakeuptime.Time = &efi_time;
@@ -689,6 +738,12 @@ static int uefirttime_test_getwaketime_invalid(
 	long ioret;
 	static uint64_t status;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_WAKEUP_TIME)) {
+		fwts_skipped(fw, "Skipping test, GetWakeupTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	status = ~0ULL;
 	getwakeuptime->status = &status;
 
@@ -779,6 +834,12 @@ static int uefirttime_test23(fwts_framework *fw)
 	struct efi_getwakeuptime getwakeuptime;
 	uint8_t enabled, pending;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_TIME)) {
+		fwts_skipped(fw, "Skipping test, GetTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	gettime.Capabilities = &efi_time_cap;
 	gettime.Time = &oldtime;
 	gettime.status = &status;
@@ -797,6 +858,12 @@ static int uefirttime_test23(fwts_framework *fw)
 		return FWTS_ERROR;
 	}
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_WAKEUP_TIME)) {
+		fwts_skipped(fw, "Skipping test, SetWakeupTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	/* change the hour, add 1 hour*/
 	addonehour(&oldtime);
 
@@ -820,6 +887,12 @@ static int uefirttime_test23(fwts_framework *fw)
 
 	sleep(1);
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_WAKEUP_TIME)) {
+		fwts_skipped(fw, "Skipping test, SetWakeupTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	getwakeuptime.Enabled = &enabled;
 	getwakeuptime.Pending = &pending;
 	getwakeuptime.Time = &newtime;
@@ -847,7 +920,7 @@ static int uefirttime_test23(fwts_framework *fw)
 
 	if (*getwakeuptime.Pending != false) {
 		fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetWakeupTimePending",
-			"Get error alarm signle status.");
+			"Get error alarm signal status.");
 		return FWTS_ERROR;
 	}
 
@@ -909,6 +982,12 @@ static int uefirttime_test_setwakeuptime_invalid(
 	long ioret;
 	static uint64_t status;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_WAKEUP_TIME)) {
+		fwts_skipped(fw, "Skipping test, SetWakeupTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	status = ~0ULL;
 	setwakeuptime->status = &status;
 
@@ -956,6 +1035,12 @@ static int uefirttime_test_setwakeuptime_invalid_time(
 	uint8_t pending, enabled;
 	int ret, ioret;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_WAKEUP_TIME)) {
+		fwts_skipped(fw, "Skipping test, GetWakeupTime runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	getwakeuptime.Enabled = &enabled;
 	getwakeuptime.Pending = &pending;
 	getwakeuptime.Time = &oldtime;
@@ -998,6 +1083,9 @@ static int uefirttime_test_setwakeuptime_invalid_time(
 
 	ret = uefirttime_test_setwakeuptime_invalid(fw, &setwakeuptime);
 
+	if (ret == FWTS_SKIP)
+		return ret;
+
 	/* Restore original time */
 	setwakeuptime.Time = &oldtime;
 	status = ~0ULL;
@@ -1159,202 +1247,138 @@ static int uefirttime_test38(fwts_framework *fw)
 	EFI_TIME efi_time;
 	EFI_TIME_CAPABILITIES efi_time_cap;
 
-	if (!have_rtsupported) {
-		fwts_skipped(fw, "Cannot get the RuntimeServicesSupported "
-				 "mask from the kernel. This IOCTL was "
-				 "introduced in Linux v5.11.");
-		return FWTS_SKIP;
-	}
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_TIME)) {
+		gettime.Capabilities = &efi_time_cap;
+		gettime.Time = &efi_time;
+		gettime.status = &status;
 
-	gettime.Capabilities = &efi_time_cap;
-	gettime.Time = &efi_time;
-	gettime.status = &status;
-	ioret = ioctl(fd, EFI_RUNTIME_GET_TIME, &gettime);
-	if (ioret == -1) {
-		if (status == EFI_UNSUPPORTED) {
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_TIME) {
-				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetTime",
-					"Get the GetTime runtime service supported "
-					"via RuntimeServicesSupported mask. "
-					"But actually is not supported by firmware.");
-			} else {
+		ioret = ioctl(fd, EFI_RUNTIME_GET_TIME, &gettime);
+		if (ioret == -1) {
+			if (status == EFI_UNSUPPORTED)
 				fwts_passed(fw, "UEFI GetTime runtime service "
-					"supported status test passed.");
+					"unsupported status test passed.");
+			else {
+				if (status == ~0ULL)
+					fwts_skipped(fw, "Unknown error occurred, skip test.");
+				else
+					fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetTime",
+						"Get the GetTime runtime service unsupported "
+						"via RuntimeServicesSupported mask. "
+						"But actually is supported by firmware.");
 			}
 		} else {
-			if (status == ~0ULL) {
+			if (status != EFI_SUCCESS )
 				fwts_skipped(fw, "Unknown error occurred, skip test.");
-				return FWTS_SKIP;
-			}
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_TIME) {
-				fwts_passed(fw, "UEFI GetTime runtime service "
-					"supported status test passed.");
-			} else {
+			else
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetTime",
 					"Get the GetTime runtime service unsupported "
 					"via RuntimeServicesSupported mask. "
 					"But actually is supported by firmware.");
-			}
 		}
-	} else {
-		if (status != EFI_SUCCESS ) {
-			fwts_skipped(fw, "Unknown error occurred, skip test.");
-			return FWTS_SKIP;
-		}
-		if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_TIME) {
-			fwts_passed(fw, "UEFI GetTime runtime service "
-				"supported status test passed.");
-		} else {
-			fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetTime",
-				"Get the GetTime runtime service unsupported "
-				"via RuntimeServicesSupported mask. "
-				"But actually is supported by firmware.");
-		}
-	}
+	} else
+		fwts_skipped(fw, "GetTime runtime service supported, skip test.");
 
-	settime.Time = &efi_time;
-	status = ~0ULL;
-	settime.status = &status;
+	/* set test time for settime and setwakeuptime tests */
+	memset(&efi_time, 0, sizeof(efi_time));
+	efi_time.Year = 2000;
+	efi_time.Month = 1;
+	efi_time.Day = 1;
 
-	ioret = ioctl(fd, EFI_RUNTIME_SET_TIME, &settime);
-	if (ioret == -1) {
-		if (status == EFI_UNSUPPORTED) {
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_SET_TIME) {
-				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetTime",
-					"Get the SetTime runtime service supported "
-					"via RuntimeServicesSupported mask. "
-					"But actually is not supported by firmware.");
-			} else {
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_TIME)) {
+		settime.Time = &efi_time;
+		status = ~0ULL;
+		settime.status = &status;
+
+		ioret = ioctl(fd, EFI_RUNTIME_SET_TIME, &settime);
+		if (ioret == -1) {
+			if (status == EFI_UNSUPPORTED) {
 				fwts_passed(fw, "UEFI SetTime runtime service "
-					"supported status test passed.");
+					"unsupported status test passed.");
+			} else {
+				if (status == ~0ULL)
+					fwts_skipped(fw, "Unknown error occurred, skip test.");
+				else
+					fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetTime",
+						"Get the SetTime runtime service unsupported "
+						"via RuntimeServicesSupported mask. "
+						"But actually is supported by firmware.");
 			}
 		} else {
-			if (status == ~0ULL) {
+			if (status != EFI_SUCCESS )
 				fwts_skipped(fw, "Unknown error occurred, skip test.");
-				return FWTS_SKIP;
-			}
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_SET_TIME) {
-				fwts_passed(fw, "UEFI SetTime runtime service "
-					"supported status test passed.");
-			} else {
+			else
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetTime",
 					"Get the SetTime runtime service unsupported "
 					"via RuntimeServicesSupported mask. "
 					"But actually is supported by firmware.");
-			}
 		}
-	} else {
-		if (status != EFI_SUCCESS ) {
-			fwts_skipped(fw, "Unknown error occurred, skip test.");
-			return FWTS_SKIP;
-		}
-		if (runtimeservicessupported & EFI_RT_SUPPORTED_SET_TIME) {
-			fwts_passed(fw, "UEFI SetTime runtime service "
-				"supported status test passed.");
-		} else {
-			fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetTime",
-				"Get the SetTime runtime service unsupported "
-				"via RuntimeServicesSupported mask. "
-				"But actually is supported by firmware.");
-		}
-	}
+	} else
+		fwts_skipped(fw, "SetTime runtime service supported, skip test.");
 
-	setwakeuptime.Time = &efi_time;
-	status = ~0ULL;
-	setwakeuptime.status = &status;
-	setwakeuptime.Enabled = false;
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_WAKEUP_TIME)) {
+		setwakeuptime.Time = &efi_time;
+		status = ~0ULL;
+		setwakeuptime.status = &status;
+		setwakeuptime.Enabled = false;
 
-	ioret = ioctl(fd, EFI_RUNTIME_SET_WAKETIME, &setwakeuptime);
-	if (ioret == -1) {
-		if (status == EFI_UNSUPPORTED) {
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_SET_WAKEUP_TIME) {
-				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetWakeupTime",
-					"Get the SetWakeupTime runtime service supported "
-					"via RuntimeServicesSupported mask. "
-					"But actually is not supported by firmware");
-
-			} else {
-					fwts_passed(fw, "UEFI SetWakeupTime runtime service "
-						"supported status test passed.");
+		ioret = ioctl(fd, EFI_RUNTIME_SET_WAKETIME, &setwakeuptime);
+		if (ioret == -1) {
+			if (status == EFI_UNSUPPORTED)
+						fwts_passed(fw, "UEFI SetWakeupTime runtime service "
+							"unsupported status test passed.");
+			else {
+				if (status == ~0ULL)
+					fwts_skipped(fw, "Unknown error occurred, skip test.");
+				else
+					fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetWakeupTime",
+						"Get the SetWakeupTime runtime service unsupported "
+						"via RuntimeServicesSupported mask. "
+						"But actually is supported by firmware.");
 			}
 		} else {
-			if (status == ~0ULL) {
+			if (status != EFI_SUCCESS )
 				fwts_skipped(fw, "Unknown error occurred, skip test.");
-				return FWTS_SKIP;
-			}
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_SET_WAKEUP_TIME) {
-				fwts_passed(fw, "UEFI SetWakeupTime runtime service "
-					"supported status test passed.");
-			} else {
+			else
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetWakeupTime",
 					"Get the SetWakeupTime runtime service unsupported "
 					"via RuntimeServicesSupported mask. "
 					"But actually is supported by firmware.");
-			}
-		}
-	} else {
-		if (status != EFI_SUCCESS ) {
-			fwts_skipped(fw, "Unknown error occurred, skip test.");
-			return FWTS_SKIP;
-		}
-		if (runtimeservicessupported & EFI_RT_SUPPORTED_SET_WAKEUP_TIME) {
-			fwts_passed(fw, "UEFI SetWakeupTime runtime service "
-				"supported status test passed.");
-		} else {
-			fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetWakeupTime",
-				"Get the SetWakeupTime runtime service unsupported "
-				"via RuntimeServicesSupported mask. "
-				"But actually is supported by firmware.");
 		}
 	}
+	else
+		fwts_skipped(fw, "SetWakeupTime runtime service supported, skip test.");
 
-	getwakeuptime.Enabled = &enabled;
-	getwakeuptime.Pending = &pending;
-	getwakeuptime.Time = &efi_time;
-	getwakeuptime.status = &status;
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_WAKEUP_TIME)) {
+		getwakeuptime.Enabled = &enabled;
+		getwakeuptime.Pending = &pending;
+		getwakeuptime.Time = &efi_time;
+		getwakeuptime.status = &status;
 
-	ioret = ioctl(fd, EFI_RUNTIME_GET_WAKETIME, &getwakeuptime);
-	if (ioret == -1) {
-		if (status == EFI_UNSUPPORTED) {
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_WAKEUP_TIME) {
-				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetWakeupTime",
-					"Get the GetWakeupTime runtime service supported "
-					"via RuntimeServicesSupported mask. "
-					"But actually is not supported by firmware");
-			} else {
-				fwts_passed(fw, "UEFI GetWakeupTime runtime service "
-					"supported status test passed.");
+		ioret = ioctl(fd, EFI_RUNTIME_GET_WAKETIME, &getwakeuptime);
+		if (ioret == -1) {
+			if (status == EFI_UNSUPPORTED)
+					fwts_passed(fw, "UEFI GetWakeupTime runtime service "
+						"unsupported status test passed.");
+			else {
+				if (status == ~0ULL)
+					fwts_skipped(fw, "Unknown error occurred, skip test.");
+				else
+					fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetWakeupTime",
+						"Get the GetWakeupTime runtime service unsupported "
+						"via RuntimeServicesSupported mask. "
+						"But actually is supported by firmware");
 			}
 		} else {
-			if (status == ~0ULL) {
+			if (status != EFI_SUCCESS )
 				fwts_skipped(fw, "Unknown error occurred, skip test.");
-				return FWTS_SKIP;
-			}
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_WAKEUP_TIME) {
-				fwts_passed(fw, "UEFI GetWakeupTime runtime service "
-					"supported status test passed.");
-			} else {
+			else
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetWakeupTime",
 					"Get the GetWakeupTime runtime service unsupported "
 					"via RuntimeServicesSupported mask. "
 					"But actually is supported by firmware");
-			}
 		}
-	} else {
-		if (status != EFI_SUCCESS ){
-			fwts_skipped(fw, "Unknow error occurred, skip test.");
-			return FWTS_SKIP;
-		}
-		if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_WAKEUP_TIME) {
-			fwts_passed(fw, "UEFI GetWakeupTime runtime service "
-				"supported status test passed.");
-		} else {
-			fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetWakeupTime",
-				"Get the GetWakeupTime runtime service unsupported "
-				"via RuntimeServicesSupported mask. "
-				"But actually is supported by firmware");
-		}
-	}
+	} else
+		fwts_skipped(fw, "GetWakeupTime runtime service supported, skip test.");
 
 	return FWTS_OK;
 }
@@ -1362,7 +1386,7 @@ static int uefirttime_test38(fwts_framework *fw)
 static fwts_framework_minor_test uefirttime_tests[] = {
 	{ uefirttime_test1, "Test UEFI RT service get time interface." },
 	{ uefirttime_test2, "Test UEFI RT service get time interface, NULL time parameter." },
-	{ uefirttime_test3, "Test UEFI RT service get time interface, NULL time and NULL capabilties parameters." },
+	{ uefirttime_test3, "Test UEFI RT service get time interface, NULL time and NULL capabilities parameters." },
 
 	{ uefirttime_test4, "Test UEFI RT service set time interface." },
 	{ uefirttime_test5, "Test UEFI RT service set time interface, invalid year 1899." },
@@ -1404,7 +1428,7 @@ static fwts_framework_minor_test uefirttime_tests[] = {
 #if UEFI_IGNORE_UNSET_BITS
 	{ uefirttime_test37, "Test UEFI RT service set wakeup time interface, invalid daylight 0xfc." },
 #endif
-	{ uefirttime_test38, "Test UEFI RT time services supported status." },
+	{ uefirttime_test38, "Test UEFI RT time services unsupported status." },
 	{ NULL, NULL }
 };
 
@@ -1415,6 +1439,6 @@ static fwts_framework_ops uefirttime_ops = {
 	.minor_tests = uefirttime_tests
 };
 
-FWTS_REGISTER("uefirttime", &uefirttime_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_TEST_UEFI | FWTS_FLAG_UNSAFE | FWTS_FLAG_ROOT_PRIV | FWTS_FLAG_TEST_XBBR)
+FWTS_REGISTER("uefirttime", &uefirttime_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_UEFI | FWTS_FLAG_UNSAFE | FWTS_FLAG_ROOT_PRIV | FWTS_FLAG_XBBR)
 
 #endif
