@@ -64,7 +64,6 @@ static uint16_t variablenametest[] = {'T', 'e', 's', 't', 'v', 'a', 'r', '\0'};
 static uint16_t variablenametest2[] = {'T', 'e', 's', 't', 'v', 'a', 'r', ' ', '\0'};
 static uint16_t variablenametest3[] = {'T', 'e', 's', 't', 'v', 'a', '\0'};
 
-static bool have_rtsupported;
 static uint32_t runtimeservicessupported;
 
 static void uefirtvariable_env_cleanup(void)
@@ -103,8 +102,7 @@ static int uefirtvariable_init(fwts_framework *fw)
 
 	uefirtvariable_env_cleanup();
 
-	fwts_uefi_rt_support_status_get(fd, &have_rtsupported,
-			&runtimeservicessupported);
+	fwts_uefi_rt_support_status_get(fd, &runtimeservicessupported);
 
 	return FWTS_OK;
 }
@@ -131,11 +129,17 @@ static int getvariable_test(
 	uint8_t testdata[MAX_DATA_LENGTH];
 	uint64_t dataindex;
 	uint64_t getdatasize = sizeof(testdata);
-	uint32_t attributestest;
+	uint32_t attributestest = 0;
 
 	uint8_t data[datasize];
 	uint32_t i;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE)) {
+		fwts_skipped(fw, "Skipping test, SetVariable runtime service "
+			"is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	for (dataindex = 0; dataindex < datasize; dataindex++)
 		data[dataindex] = (uint8_t)dataindex;
 
@@ -171,6 +175,12 @@ static int getvariable_test(
 		return FWTS_ERROR;
 	}
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE)) {
+		fwts_skipped(fw, "Skipping test, GetVariable runtime service "
+			"is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	getvariable.VariableName = varname;
 	getvariable.VendorGuid = &gtestguid1;
 	getvariable.Attributes = &attributestest;
@@ -313,6 +323,12 @@ static int getnextvariable_test1(fwts_framework *fw)
 	bool found_name = false, found_guid = false;
 	int ret = FWTS_OK;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE)) {
+		fwts_skipped(fw, "Skipping test, SetVariable runtime service "
+			"is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	for (dataindex = 0; dataindex < datasize; dataindex++)
 		data[dataindex] = (uint8_t)dataindex;
 
@@ -348,6 +364,12 @@ static int getnextvariable_test1(fwts_framework *fw)
 		return FWTS_ERROR;
 	}
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME)) {
+		fwts_skipped(fw, "Skipping test, GetNextVariableName runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	variablename = malloc(sizeof(uint16_t) * variablenamesize);
 	if (!variablename) {
 		fwts_skipped(fw, "Unable to alloc memory for variable name");
@@ -499,6 +521,12 @@ static int getnextvariable_test2(fwts_framework *fw)
 	EFI_GUID vendorguid;
 	int ret = FWTS_OK;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME)) {
+		fwts_skipped(fw, "Skipping test, GetNextVariableName runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	variablename = malloc(sizeof(uint16_t) * variablenamesize);
 	if (!variablename) {
 		fwts_skipped(fw, "Unable to alloc memory for variable name");
@@ -664,6 +692,12 @@ static int getnextvariable_test3(fwts_framework *fw)
 	EFI_GUID vendorguid;
 	int ret;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME)) {
+		fwts_skipped(fw, "Skipping test, GetNextVariableName runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	variablename = malloc(sizeof(uint16_t) * variablenamesize);
 	if (!variablename) {
 		fwts_skipped(fw, "Unable to alloc memory for variable name");
@@ -797,6 +831,12 @@ static int getnextvariable_test4(fwts_framework *fw)
 	uint16_t variablename[MAX_DATA_LENGTH];
 	EFI_GUID vendorguid;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME)) {
+		fwts_skipped(fw, "Skipping test, GetNextVariableName runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	getnextvariablename.VariableNameSize = &variablenamesize;
 	getnextvariablename.VendorGuid = &vendorguid;
 	getnextvariablename.status = &status;
@@ -914,6 +954,12 @@ static int setvariable_insertvariable(
 
 	uint8_t data[datasize + 1];
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE)) {
+		fwts_skipped(fw, "Skipping test, SetVariable runtime service "
+			"is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	for (dataindex = 0; dataindex < datasize; dataindex++)
 		data[dataindex] = (uint8_t)dataindex + datadiff;
 
@@ -989,6 +1035,12 @@ static int setvariable_checkvariable(
 	uint64_t getdatasize = sizeof(testdata);
 	uint32_t attributestest;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE)) {
+		fwts_skipped(fw, "Skipping test, GetVariable runtime service "
+			"is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	getvariable.VariableName = varname;
 	getvariable.VendorGuid = gtestguid;
 	getvariable.Attributes = &attributestest;
@@ -1049,6 +1101,12 @@ static int setvariable_checkvariable_notfound(
 	uint64_t getdatasize = sizeof(testdata);
 	uint32_t attributestest;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE)) {
+		fwts_skipped(fw, "Skipping test, GetVariable runtime service "
+			"is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	getvariable.VariableName = varname;
 	getvariable.VendorGuid = gtestguid;
 	getvariable.Attributes = &attributestest;
@@ -1088,6 +1146,13 @@ static int setvariable_invalidattr(
 	uint64_t dataindex;
 	uint8_t data[datasize];
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE)) {
+		fwts_skipped(fw, "Skipping test, SetVariable runtime service "
+			"is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
+
 	for (dataindex = 0; dataindex < datasize; dataindex++)
 		data[dataindex] = (uint8_t)dataindex + datadiff;
 
@@ -1439,6 +1504,12 @@ static int setvariable_test8(fwts_framework *fw)
 	uint8_t data = 1;
 	uint64_t status = ~0ULL;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE)) {
+		fwts_skipped(fw, "Skipping test, SetVariable runtime service "
+			"is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	setvariable.VariableName = variablenametest;
 	setvariable.VendorGuid = &gtestguid1;
 	setvariable.Attributes = attr;
@@ -1502,6 +1573,12 @@ static int getnextvariable_multitest(
 	uint16_t variablename[MAX_DATA_LENGTH];
 	EFI_GUID vendorguid;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE)) {
+		fwts_skipped(fw, "Skipping test, SetVariable runtime service "
+			"is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	for (dataindex = 0; dataindex < datasize; dataindex++)
 		data[dataindex] = (uint8_t)dataindex;
 
@@ -1536,6 +1613,12 @@ static int getnextvariable_multitest(
 		return FWTS_ERROR;
 	}
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME)) {
+		fwts_skipped(fw, "Skipping test, GetNextVariableName runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	getnextvariablename.VariableNameSize = &variablenamesize;
 	getnextvariablename.VariableName = variablename;
 	getnextvariablename.VendorGuid = &vendorguid;
@@ -1699,6 +1782,12 @@ static int uefirtvariable_test4(fwts_framework *fw)
 	uint64_t remvarstoragesize;
 	uint64_t maxvariablesize;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_QUERY_VARIABLE_INFO)) {
+		fwts_skipped(fw, "Skipping test, QueryVariableInfo runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	if (do_queryvariableinfo(&status, &remvarstoragesize, &maxvariablesize) == FWTS_ERROR) {
 		if (status == EFI_UNSUPPORTED) {
 			fwts_skipped(fw,
@@ -1848,6 +1937,12 @@ static int uefirtvariable_test7(fwts_framework *fw)
 	fwts_log_info(fw, "Testing QueryVariableInfo on querying the variable %" PRIu32
 		" times.", uefi_query_variable_multiple);
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_QUERY_VARIABLE_INFO)) {
+		fwts_skipped(fw, "Skipping test, QueryVariableInfo runtime "
+			"service is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	/* first check if the firmware support QueryVariableInfo interface */
 	if (do_queryvariableinfo(&status, &remvarstoragesize, &maxvariablesize) == FWTS_ERROR) {
 		if (status == EFI_UNSUPPORTED) {
@@ -1892,6 +1987,12 @@ static void getvariable_test_invalid(
 {
 	long ioret;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE)) {
+		fwts_skipped(fw, "Skipping test, GetVariable runtime service "
+			"is not supported on this platform.");
+		return;
+	}
+
 	fwts_log_info(fw, "Testing GetVariable with %s.", test);
 	*(getvariable->status) = ~0ULL;
 
@@ -1935,6 +2036,12 @@ static int uefirtvariable_test8(fwts_framework *fw)
 	uint32_t attr;
 	int ioret;
 
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE)) {
+		fwts_skipped(fw, "Skipping test, SetVariable runtime service "
+			"is not supported on this platform.");
+		return FWTS_SKIP;
+	}
+
 	for (dataindex = 0; dataindex < sizeof(data); dataindex++)
 		data[dataindex] = (uint8_t)dataindex;
 
@@ -2044,225 +2151,159 @@ static int uefirtvariable_test9(fwts_framework *fw)
 	uint64_t getdatasize = sizeof(testdata);
 	uint32_t attr;
 
-	if (!have_rtsupported) {
-		fwts_skipped(fw, "Cannot get the RuntimeServicesSupported "
-				 "mask from the kernel. This IOCTL was "
-				 "introduced in Linux v5.11.");
-		return FWTS_SKIP;
-	}
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE)) {
+		setvariable.VariableName = variablenametest;
+		setvariable.VendorGuid = &gtestguid1;
+		setvariable.Attributes = attributes;
+		setvariable.DataSize = datasize;
+		setvariable.Data = &data;
+		setvariable.status = &status;
 
-	setvariable.VariableName = variablenametest;
-	setvariable.VendorGuid = &gtestguid1;
-	setvariable.Attributes = attributes;
-	setvariable.DataSize = datasize;
-	setvariable.Data = &data;
-	setvariable.status = &status;
-
-	ioret = ioctl(fd, EFI_RUNTIME_SET_VARIABLE, &setvariable);
-	if (ioret == -1) {
-		if (status == EFI_UNSUPPORTED) {
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE) {
-				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetVariable",
-					"Get the Setvariable runtime service supported "
-					"via RuntimeServicesSupported mask. "
-					"But actually is not supported by firmware.");
-			} else {
+		ioret = ioctl(fd, EFI_RUNTIME_SET_VARIABLE, &setvariable);
+		if (ioret == -1) {
+			if (status == EFI_UNSUPPORTED)
 				fwts_passed(fw, "UEFI SetVariable runtime service "
-					"supported status test passed.");
+					"unsupported status test passed.");
+			else {
+				if (status == ~0ULL)
+					fwts_skipped(fw, "Unknown error occurred, skip test.");
+				else
+					fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetVariable",
+						"Get the SetVariable runtime service unsupported "
+						"via RuntimeServicesSupported mask. "
+						"But actually is supported by firmware.");
 			}
 		} else {
-			if (status == ~0ULL) {
+			if (status != EFI_SUCCESS)
 				fwts_skipped(fw, "Unknown error occurred, skip test.");
-				return FWTS_SKIP;
-			}
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE) {
-				fwts_passed(fw, "UEFI SetVariable runtime service "
-					"supported status test passed.");
-			} else {
+			else
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetVariable",
 					"Get the SetVariable runtime service unsupported "
 					"via RuntimeServicesSupported mask. "
 					"But actually is supported by firmware.");
-			}
-		}
-	} else {
-		if (status != EFI_SUCCESS ) {
-			fwts_skipped(fw, "Unknown error occurred, skip test.");
-			return FWTS_SKIP;
-		}
-		if (runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE) {
-			fwts_passed(fw, "UEFI SetVariable runtime service "
-				"supported status test passed.");
-		} else {
-			fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetVariable",
-				"Get the SetVariable runtime service unsupported "
-				"via RuntimeServicesSupported mask. "
-				"But actually is supported by firmware.");
 		}
 	}
+	else
+		fwts_skipped(fw, "SetVariable runtime service supported, skip test.");
 
-	getvariable.VariableName = variablenametest;
-	getvariable.VendorGuid = &gtestguid1;
-	getvariable.Attributes = &attr;
-	getvariable.DataSize = &getdatasize;
-	getvariable.Data = testdata;
-	getvariable.status = &status;
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE)) {
+		getvariable.VariableName = variablenametest;
+		getvariable.VendorGuid = &gtestguid1;
+		getvariable.Attributes = &attr;
+		getvariable.DataSize = &getdatasize;
+		getvariable.Data = testdata;
+		getvariable.status = &status;
 
-	ioret = ioctl(fd, EFI_RUNTIME_GET_VARIABLE, &getvariable);
-	if (ioret == -1) {
-		if (status == EFI_UNSUPPORTED) {
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE) {
-				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetVariable",
-					"Get the GetVariable runtime service supported "
-					"via RuntimeServicesSupported mask. "
-					"But actually is not supported by firmware.");
-			} else {
+		ioret = ioctl(fd, EFI_RUNTIME_GET_VARIABLE, &getvariable);
+		if (ioret == -1) {
+			if (status == EFI_UNSUPPORTED)
 				fwts_passed(fw, "UEFI GetVariable runtime service "
-					"supported status test passed.");
+					"unsupported status test passed.");
+			else {
+				if (status == ~0ULL)
+					fwts_skipped(fw, "Unknown error occurred, skip test.");
+				else
+					fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetVariable",
+						"Get the GetVariable runtime service unsupported "
+						"via RuntimeServicesSupported mask. "
+						"But actually is supported by firmware.");
 			}
 		} else {
-			if (status == ~0ULL) {
+			if (status != EFI_SUCCESS)
 				fwts_skipped(fw, "Unknown error occurred, skip test.");
-				return FWTS_SKIP;
-			}
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE) {
-				fwts_passed(fw, "UEFI GetVariable runtime service "
-					"supported status test passed.");
-			} else {
+			else
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetVariable",
 					"Get the GetVariable runtime service unsupported "
 					"via RuntimeServicesSupported mask. "
 					"But actually is supported by firmware.");
-			}
 		}
-	} else {
-		if (status != EFI_SUCCESS ) {
-			fwts_skipped(fw, "Unknown error occurred, skip test.");
-			return FWTS_SKIP;
-		}
-		if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE) {
-			fwts_passed(fw, "UEFI GetVariable runtime service "
-				"supported status test passed.");
-		} else {
-			fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetVariable",
-				"Get the GetVariable runtime service unsupported "
-				"via RuntimeServicesSupported mask. "
-				"But actually is supported by firmware.");
-		}
-	}
+	} else
+		fwts_skipped(fw, "GetVariable runtime service supported, skip test.");
 
 	/* delete the variable which was set */
 	setvariable.DataSize = 0;
 	status = ~0ULL;
-	ioctl(fd, EFI_RUNTIME_SET_VARIABLE, &setvariable);
+	(void)ioctl(fd, EFI_RUNTIME_SET_VARIABLE, &setvariable);
 
 	variablename = malloc(sizeof(uint16_t) * variablenamesize);
 	if (!variablename) {
 		fwts_skipped(fw, "Unable to alloc memory for variable name");
 		return FWTS_SKIP;
 	}
-	getnextvariablename.VariableNameSize = &variablenamesize;
-	getnextvariablename.VariableName = variablename;
-	getnextvariablename.VendorGuid = &guid;
-	getnextvariablename.status = &status;
 
-	variablename[0] = '\0';
-	status = ~0ULL;
-	ioret = ioctl(fd, EFI_RUNTIME_GET_NEXTVARIABLENAME, &getnextvariablename);
-	if (ioret == -1) {
-		if (status == EFI_UNSUPPORTED) {
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME) {
-				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetNextVarName",
-					"Get the GetNextVarName runtime service supported "
-					"via RuntimeServicesSupported mask. "
-					"But actually is not supported by firmware.");
-			} else {
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME)) {
+		getnextvariablename.VariableNameSize = &variablenamesize;
+		getnextvariablename.VariableName = variablename;
+		getnextvariablename.VendorGuid = &guid;
+		getnextvariablename.status = &status;
+		variablename[0] = '\0';
+		status = ~0ULL;
+
+		ioret = ioctl(fd, EFI_RUNTIME_GET_NEXTVARIABLENAME, &getnextvariablename);
+		if (ioret == -1) {
+			if (status == EFI_UNSUPPORTED)
 				fwts_passed(fw, "UEFI GetNextVarName runtime service "
-					"supported status test passed.");
+					"unsupported status test passed.");
+			else {
+				if (status == ~0ULL)
+					fwts_skipped(fw, "Unknown error occurred, skip test.");
+				else
+					fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetNextVarName",
+						"Get the GetNextVarName runtime service unsupported "
+						"via RuntimeServicesSupported mask. "
+						"But actually is supported by firmware.");
 			}
 		} else {
-			if (status == ~0ULL) {
+			if (status != EFI_SUCCESS)
 				fwts_skipped(fw, "Unknown error occurred, skip test.");
-				return FWTS_SKIP;
-			}
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME) {
-				fwts_passed(fw, "UEFI GetNextVarName runtime service "
-					"supported status test passed.");
-			} else {
+			else
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetNextVarName",
 					"Get the GetNextVarName runtime service unsupported "
 					"via RuntimeServicesSupported mask. "
 					"But actually is supported by firmware.");
-			}
 		}
-	} else {
-		if (status != EFI_SUCCESS ) {
-			fwts_skipped(fw, "Unknown error occurred, skip test.");
-			return FWTS_SKIP;
-		}
-		if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME) {
-			fwts_passed(fw, "UEFI GetNextVarName runtime service "
-				"supported status test passed.");
-		} else {
-			fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetNextVarName",
-				"Get the GetNextVarName runtime service unsupported "
-				"via RuntimeServicesSupported mask. "
-				"But actually is supported by firmware.");
-		}
-	}
+	} else
+		fwts_skipped(fw, "GetNextVarName runtime service supported, skip test.");
 
-	queryvariableinfo.Attributes = attributes;
-	queryvariableinfo.MaximumVariableStorageSize = &maxvarstoragesize;
-	queryvariableinfo.RemainingVariableStorageSize = &remvarstoragesize;
-	queryvariableinfo.MaximumVariableSize = &maxvariablesize;
-	queryvariableinfo.status = &status;
-	status = ~0ULL;
+	if (!(runtimeservicessupported & EFI_RT_SUPPORTED_QUERY_VARIABLE_INFO)) {
+		queryvariableinfo.Attributes = attributes;
+		queryvariableinfo.MaximumVariableStorageSize = &maxvarstoragesize;
+		queryvariableinfo.RemainingVariableStorageSize = &remvarstoragesize;
+		queryvariableinfo.MaximumVariableSize = &maxvariablesize;
+		queryvariableinfo.status = &status;
+		status = ~0ULL;
 
-	ioret = ioctl(fd, EFI_RUNTIME_QUERY_VARIABLEINFO, &queryvariableinfo);
-	if (ioret == -1) {
-		if (status == EFI_UNSUPPORTED) {
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_QUERY_VARIABLE_INFO) {
-				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeQueryVarInfo",
-					"Get the QueryVarInfo runtime service supported "
-					"via RuntimeServicesSupported mask. "
-					"But actually is not supported by firmware.");
-			} else {
+		ioret = ioctl(fd, EFI_RUNTIME_QUERY_VARIABLEINFO, &queryvariableinfo);
+		if (ioret == -1) {
+			if (status == EFI_UNSUPPORTED)
 				fwts_passed(fw, "UEFI QueryVarInfo runtime service "
-					"supported status test passed.");
+					"unsupported status test passed.");
+			else {
+				if (status == ~0ULL)
+					fwts_skipped(fw, "Unknown error occurred, skip test.");
+				else
+					fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeQueryVarInfo",
+						"Get the QueryVarInfo runtime service unsupported "
+						"via RuntimeServicesSupported mask. "
+						"But actually is supported by firmware.");
 			}
 		} else {
-			if (status == ~0ULL) {
+			if (status != EFI_SUCCESS)
 				fwts_skipped(fw, "Unknown error occurred, skip test.");
-				return FWTS_SKIP;
-			}
-			if (runtimeservicessupported & EFI_RT_SUPPORTED_QUERY_VARIABLE_INFO) {
-				fwts_passed(fw, "UEFI QueryVarInfo runtime service "
-					"supported status test passed.");
-			} else {
+			else {
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeQueryVarInfo",
 					"Get the QueryVarInfo runtime service unsupported "
 					"via RuntimeServicesSupported mask. "
 					"But actually is supported by firmware.");
 			}
 		}
-	} else {
-		if (status != EFI_SUCCESS ) {
-			fwts_skipped(fw, "Unknown error occurred, skip test.");
-			return FWTS_SKIP;
-		}
-		if (runtimeservicessupported & EFI_RT_SUPPORTED_QUERY_VARIABLE_INFO) {
-			fwts_passed(fw, "UEFI QueryVarInfo runtime service "
-				"supported status test passed.");
-		} else {
-			fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeQueryVarInfo",
-				"Get the QueryVarInfo runtime service unsupported "
-				"via RuntimeServicesSupported mask. "
-				"But actually is supported by firmware.");
-		}
-	}
+	} else
+		fwts_skipped(fw, "QueryVarInfo runtime service supported, skip test.");
+
+	if (variablename)
+		free(variablename);
 
 	return FWTS_OK;
-
 }
 
 static int options_check(fwts_framework *fw)
@@ -2336,7 +2377,7 @@ static fwts_framework_minor_test uefirtvariable_tests[] = {
 	{ uefirtvariable_test6, "Test UEFI RT service set variable interface stress test." },
 	{ uefirtvariable_test7, "Test UEFI RT service query variable info interface stress test." },
 	{ uefirtvariable_test8, "Test UEFI RT service get variable interface, invalid parameters." },
-	{ uefirtvariable_test9, "Test UEFI RT variable services supported status." },
+	{ uefirtvariable_test9, "Test UEFI RT variable services unsupported status." },
 	{ NULL, NULL }
 };
 
@@ -2350,6 +2391,6 @@ static fwts_framework_ops uefirtvariable_ops = {
 	.options_check   = options_check,
 };
 
-FWTS_REGISTER("uefirtvariable", &uefirtvariable_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_TEST_UEFI | FWTS_FLAG_UNSAFE | FWTS_FLAG_ROOT_PRIV | FWTS_FLAG_TEST_XBBR)
+FWTS_REGISTER("uefirtvariable", &uefirtvariable_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_UEFI | FWTS_FLAG_UNSAFE | FWTS_FLAG_ROOT_PRIV | FWTS_FLAG_XBBR)
 
 #endif
